@@ -23,4 +23,4 @@ done
 echo $DOCKERHUB_TOKEN | docker login --password-stdin -u $DOCKERHUB_USERNAME
 
 #Run all the e2e tests
-cd /github.com/aws/copilot-cli/e2e/$TEST_SUITE && /go/bin/ginkgo -v -r
+cd /github.com/aws/copilot-cli/e2e/$TEST_SUITE && /go/bin/ginkgo -v -r --timeout=1h30m
\ No newline at end of file
