@@ -14,7 +14,7 @@ import (
 
 	"github.com/aws/copilot-cli/e2e/internal/client"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 )
 
