@@ -74,6 +74,15 @@ func (a *AppRunner) DescribeService(svcARN string) (*Service, error) {
 	}
 	sort.SliceStable(envVars, func(i int, j int) bool { return envVars[i].Name < envVars[j].Name })
 
+	var secrets []*EnvironmentSecret
+	for k, v := range resp.Service.SourceConfiguration.ImageRepository.ImageConfiguration.RuntimeEnvironmentSecrets {
+		secrets = append(secrets, &EnvironmentSecret{
+			Name:  k,
+			Value: aws.StringValue(v),
+		})
+	}
+	sort.SliceStable(secrets, func(i int, j int) bool { return secrets[i].Name < secrets[j].Name })
+
 	var observabilityConfiguration ObservabilityConfiguration
 	if resp.Service.ObservabilityConfiguration != nil && aws.BoolValue(resp.Service.ObservabilityConfiguration.ObservabilityEnabled) {
 		if out, err := a.client.DescribeObservabilityConfiguration(&apprunner.DescribeObservabilityConfigurationInput{
@@ -100,6 +109,7 @@ func (a *AppRunner) DescribeService(svcARN string) (*Service, error) {
 		ImageID:              *resp.Service.SourceConfiguration.ImageRepository.ImageIdentifier,
 		Port:                 *resp.Service.SourceConfiguration.ImageRepository.ImageConfiguration.Port,
 		Observability:        observabilityConfiguration,
+		EnvironmentSecrets:   secrets,
 	}, nil
 }
 
