@@ -52,6 +52,10 @@ func TestAppRunner_DescribeService(t *testing.T) {
 										"LOG_LEVEL":                "info",
 										"COPILOT_APPLICATION_NAME": "testapp",
 									}),
+									RuntimeEnvironmentSecrets: aws.StringMap(map[string]string{
+										"zzz123":        "parameter/zzz123",
+										"my-ssm-secret": "arn:aws:ssm:us-east-1:111111111111:parameter/jan11ssm",
+									}),
 									Port: aws.String("80"),
 								},
 							},
@@ -77,6 +81,16 @@ func TestAppRunner_DescribeService(t *testing.T) {
 						Value: "info",
 					},
 				},
+				EnvironmentSecrets: []*EnvironmentSecret{
+					{
+						Name:  "my-ssm-secret",
+						Value: "arn:aws:ssm:us-east-1:111111111111:parameter/jan11ssm",
+					},
+					{
+						Name:  "zzz123",
+						Value: "parameter/zzz123",
+					},
+				},
 				CPU:     "1024",
 				Memory:  "2048",
 				Port:    "80",
