@@ -25,6 +25,7 @@ type Service struct {
 	Port                 string
 	EnvironmentVariables []*EnvironmentVariable
 	Observability        ObservabilityConfiguration
+	EnvironmentSecrets   []*EnvironmentSecret
 }
 
 // EnvironmentVariable contains the name and value of an environment variable.
@@ -33,6 +34,12 @@ type EnvironmentVariable struct {
 	Value string
 }
 
+// EnvironmentSecret contains the name and value of a Secret from SSM Parameter Store or Secrets Manager.
+type EnvironmentSecret struct {
+	Name  string
+	Value string
+}
+
 // ObservabilityConfiguration contains observability related configuration. Currently only tracing configuration is available.
 type ObservabilityConfiguration struct {
 	TraceConfiguration *TraceConfiguration
