@@ -39,9 +39,9 @@ func (e *errCredRetrieval) Error() string {
 // RecommendActions returns recommended actions to be taken after the error.
 // Implements main.actionRecommender interface.
 func (e *errCredRetrieval) RecommendActions() string {
-	notice := "It looks like AWS credentials are misconfigured or missing"
+	notice := "It looks like your AWS credentials are misconfigured or missing"
 	if e.profile != "" {
-		notice = fmt.Sprintf("It looks like AWS profile [%s] is misconfigured or missing", e.profile)
+		notice = fmt.Sprintf("It looks like your AWS profile [%s] is misconfigured or missing", e.profile)
 	}
 	return fmt.Sprintf(`%s:
 More information: https://aws.github.io/copilot-cli/docs/credentials/`, notice)
