@@ -9,7 +9,6 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
-	"strconv"
 	"strings"
 
 	"github.com/dustin/go-humanize/english"
@@ -119,22 +118,40 @@ func logRecommendedActions(actions []string) {
 
 func indentListItem(multiline string) string {
 	var prefixedLines []string
+	var inCodeBlock bool
 	for i, line := range strings.Split(multiline, "\n") {
-		prefix := "    "
-		if i == 0 {
+		if strings.Contains(line, "```") {
+			inCodeBlock = !inCodeBlock
+		}
+		var prefix string
+		switch {
+		case i == 0:
 			prefix = "  - "
+		case inCodeBlock, strings.Contains(line, "```"):
+			prefix = ""
+		default:
+			prefix = "    "
 		}
 		prefixedLines = append(prefixedLines, fmt.Sprintf("%s%s", prefix, line))
 	}
 	return strings.Join(prefixedLines, "\n")
 }
 
-func quoteStringSlice(in []string) []string {
-	quoted := make([]string, len(in))
-	for idx, str := range in {
-		quoted[idx] = strconv.Quote(str)
+func indentBy(multiline string, indentCount int) string {
+	var prefixedLines []string
+	for _, line := range strings.Split(multiline, "\n") {
+		prefix := strings.Repeat(" ", indentCount)
+		prefixedLines = append(prefixedLines, fmt.Sprintf("%s%s", prefix, line))
 	}
-	return quoted
+	return strings.Join(prefixedLines, "\n")
+}
+
+func applyAll[T any](in []T, fn func(item T) T) []T {
+	out := make([]T, len(in))
+	for i, v := range in {
+		out[i] = fn(v)
+	}
+	return out
 }
 
 // displayPath takes any path and returns it in a form ready to be displayed to
