@@ -61,7 +61,7 @@ func (backendSvcDeployer) IsServiceAvailableInRegion(region string) (bool, error
 
 // UploadArtifacts uploads the deployment artifacts such as the container image, custom resources, addons and env files.
 func (d *backendSvcDeployer) UploadArtifacts() (*UploadArtifactsOutput, error) {
-	return d.uploadArtifacts()
+	return d.uploadArtifacts(d.uploadContainerImages, d.uploadArtifactsToS3, d.uploadCustomResources)
 }
 
 // GenerateCloudFormationTemplate generates a CloudFormation template and parameters for a workload.
@@ -83,7 +83,7 @@ func (d *backendSvcDeployer) DeployWorkload(in *DeployWorkloadInput) (ActionReco
 	if err := d.deploy(in.Options, *stackConfigOutput); err != nil {
 		return nil, err
 	}
-	return nil, nil
+	return noopActionRecommender{}, nil
 }
 
 func (d *backendSvcDeployer) stackConfiguration(in *StackRuntimeConfiguration) (*svcStackConfigurationOutput, error) {
@@ -123,23 +123,38 @@ func (d *backendSvcDeployer) stackConfiguration(in *StackRuntimeConfiguration) (
 }
 
 func (d *backendSvcDeployer) validateALBRuntime() error {
-	if d.backendMft.RoutingRule.IsEmpty() {
+	if d.backendMft.HTTP.IsEmpty() {
+		return nil
+	}
+	if err := d.validateRuntimeRoutingRule(d.backendMft.HTTP.Main); err != nil {
+		return fmt.Errorf(`validate ALB runtime configuration for "http": %w`, err)
+	}
+	for idx, rule := range d.backendMft.HTTP.AdditionalRoutingRules {
+		if err := d.validateRuntimeRoutingRule(rule); err != nil {
+			return fmt.Errorf(`validate ALB runtime configuration for "http.additional_rules[%d]": %w`, idx, err)
+		}
+	}
+	return nil
+}
+
+func (d *backendSvcDeployer) validateRuntimeRoutingRule(rule manifest.RoutingRule) error {
+	if rule.IsEmpty() {
 		return nil
 	}
 	hasImportedCerts := len(d.envConfig.HTTPConfig.Private.Certificates) != 0
 	switch {
-	case d.backendMft.RoutingRule.Alias.IsEmpty() && hasImportedCerts:
+	case rule.Alias.IsEmpty() && hasImportedCerts:
 		return &errSvcWithNoALBAliasDeployingToEnvWithImportedCerts{
 			name:    d.name,
 			envName: d.env.Name,
 		}
-	case d.backendMft.RoutingRule.Alias.IsEmpty():
+	case rule.Alias.IsEmpty():
 		return nil
 	case !hasImportedCerts:
 		return fmt.Errorf(`cannot specify "alias" in an environment without imported certs`)
 	}
 
-	aliases, err := d.backendMft.RoutingRule.Alias.ToStringSlice()
+	aliases, err := rule.Alias.ToStringSlice()
 	if err != nil {
 		return fmt.Errorf("convert aliases to string slice: %w", err)
 	}
