@@ -99,10 +99,12 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 			},
 			Manifest: &manifest.BackendService{
 				BackendServiceConfig: manifest.BackendServiceConfig{
-					RoutingRule: manifest.RoutingRuleConfiguration{
-						Alias: manifest.Alias{
-							AdvancedAliases: []manifest.AdvancedAlias{
-								{Alias: aws.String("go.dev")},
+					HTTP: manifest.HTTP{
+						Main: manifest.RoutingRule{
+							Alias: manifest.Alias{
+								AdvancedAliases: []manifest.AdvancedAlias{
+									{Alias: aws.String("go.dev")},
+								},
 							},
 						},
 					},
@@ -112,7 +114,7 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			expectedErr: `cannot specify "alias" in an environment without imported certs`,
+			expectedErr: `validate ALB runtime configuration for "http": cannot specify "alias" in an environment without imported certs`,
 		},
 		"failure if cert validation fails": {
 			App: &config.Application{
@@ -128,10 +130,12 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 			},
 			Manifest: &manifest.BackendService{
 				BackendServiceConfig: manifest.BackendServiceConfig{
-					RoutingRule: manifest.RoutingRuleConfiguration{
-						Alias: manifest.Alias{
-							AdvancedAliases: []manifest.AdvancedAlias{
-								{Alias: aws.String("go.dev")},
+					HTTP: manifest.HTTP{
+						Main: manifest.RoutingRule{
+							Alias: manifest.Alias{
+								AdvancedAliases: []manifest.AdvancedAlias{
+									{Alias: aws.String("go.dev")},
+								},
 							},
 						},
 					},
@@ -142,7 +146,7 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 				m.mockValidator.EXPECT().ValidateCertAliases([]string{"go.dev"}, []string{"mockCertARN"}).Return(errors.New("some error"))
 			},
-			expectedErr: "validate aliases against the imported certificate for env mock-env: some error",
+			expectedErr: "validate ALB runtime configuration for \"http\": validate aliases against the imported certificate for env mock-env: some error",
 		},
 		"success if cert validation succeeds": {
 			App: &config.Application{
@@ -158,10 +162,21 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 			},
 			Manifest: &manifest.BackendService{
 				BackendServiceConfig: manifest.BackendServiceConfig{
-					RoutingRule: manifest.RoutingRuleConfiguration{
-						Alias: manifest.Alias{
-							AdvancedAliases: []manifest.AdvancedAlias{
-								{Alias: aws.String("go.dev")},
+					HTTP: manifest.HTTP{
+						Main: manifest.RoutingRule{
+							Alias: manifest.Alias{
+								AdvancedAliases: []manifest.AdvancedAlias{
+									{Alias: aws.String("go.dev")},
+								},
+							},
+						},
+						AdditionalRoutingRules: []manifest.RoutingRule{
+							{
+								Alias: manifest.Alias{
+									AdvancedAliases: []manifest.AdvancedAlias{
+										{Alias: aws.String("go.test")},
+									},
+								},
 							},
 						},
 					},
@@ -171,6 +186,7 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 				m.mockValidator.EXPECT().ValidateCertAliases([]string{"go.dev"}, []string{"mockCertARN"}).Return(nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"go.test"}, []string{"mockCertARN"}).Return(nil)
 			},
 		},
 		"failure if env has imported certs but no alias set": {
@@ -187,8 +203,10 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 			},
 			Manifest: &manifest.BackendService{
 				BackendServiceConfig: manifest.BackendServiceConfig{
-					RoutingRule: manifest.RoutingRuleConfiguration{
-						Path: aws.String("/"),
+					HTTP: manifest.HTTP{
+						Main: manifest.RoutingRule{
+							Path: aws.String("/"),
+						},
 					},
 				},
 			},
@@ -196,7 +214,45 @@ func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			expectedErr: `cannot deploy service mock-svc without http.alias to environment mock-env with certificate imported`,
+			expectedErr: `validate ALB runtime configuration for "http": cannot deploy service mock-svc without "alias" to environment mock-env with certificate imported`,
+		},
+		"failure if env has imported certs but no alias set in additional rules": {
+			App: &config.Application{
+				Name: mockAppName,
+			},
+			Env: &config.Environment{
+				Name: mockEnvName,
+			},
+			inEnvironmentConfig: func() *manifest.Environment {
+				envConfig := &manifest.Environment{}
+				envConfig.HTTPConfig.Private.Certificates = []string{"mockCertARN"}
+				return envConfig
+			},
+			Manifest: &manifest.BackendService{
+				BackendServiceConfig: manifest.BackendServiceConfig{
+					HTTP: manifest.HTTP{
+						Main: manifest.RoutingRule{
+							Path: aws.String("/"),
+							Alias: manifest.Alias{
+								AdvancedAliases: []manifest.AdvancedAlias{
+									{Alias: aws.String("go.test")},
+								},
+							},
+						},
+						AdditionalRoutingRules: []manifest.RoutingRule{
+							{
+								Path: aws.String("/admin"),
+							},
+						},
+					},
+				},
+			},
+			setupMocks: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
+				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"go.test"}, []string{"mockCertARN"}).Return(nil)
+			},
+			expectedErr: `validate ALB runtime configuration for "http.additional_rules[0]": cannot deploy service mock-svc without "alias" to environment mock-env with certificate imported`,
 		},
 		"success if env has imported certs but alb not configured": {
 			App: &config.Application{
