@@ -34,6 +34,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/override"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/aws/copilot-cli/internal/pkg/template/artifactpath"
+	"github.com/aws/copilot-cli/internal/pkg/template/diff"
 	"github.com/aws/copilot-cli/internal/pkg/term/log"
 	termprogress "github.com/aws/copilot-cli/internal/pkg/term/progress"
 	"github.com/spf13/afero"
@@ -94,6 +95,7 @@ type envDeployer struct {
 	// Dependencies to deploy an environment.
 	appCFN                   appResourcesGetter
 	envDeployer              environmentDeployer
+	tmplGetter               deployedTemplateGetter
 	patcher                  patcher
 	newStack                 func(input *cfnstack.EnvConfig, forceUpdateID string, prevParams []*awscfn.Parameter) (deploycfn.StackConfiguration, error)
 	envDescriber             envDescriber
@@ -157,6 +159,7 @@ func NewEnvDeployer(in *NewEnvDeployerInput) (*envDeployer, error) {
 
 		appCFN:      deploycfn.New(defaultSession, deploycfn.WithProgressTracker(os.Stderr)),
 		envDeployer: cfnClient,
+		tmplGetter:  cfnClient,
 		patcher: &patch.EnvironmentPatcher{
 			Prog:            termprogress.NewSpinner(log.DiagnosticWriter),
 			TemplatePatcher: cfnClient,
@@ -172,7 +175,7 @@ func NewEnvDeployer(in *NewEnvDeployerInput) (*envDeployer, error) {
 		envDescriber: envDescriber,
 		lbDescriber:  elbv2.New(envManagerSession),
 		newServiceStackDescriber: func(svc string) stackDescriber {
-			return stack.NewStackDescriber(cfnstack.NameForService(in.App.Name, in.Env.Name, svc), envManagerSession)
+			return stack.NewStackDescriber(cfnstack.NameForWorkload(in.App.Name, in.Env.Name, svc), envManagerSession)
 		},
 
 		ws: in.Workspace,
@@ -220,6 +223,23 @@ func (d *envDeployer) UploadArtifacts() (*UploadEnvArtifactsOutput, error) {
 	}, nil
 }
 
+// DeployDiff returns the stringified diff of the template against the deployed template of the environment.
+func (d *envDeployer) DeployDiff(template string) (string, error) {
+	tmpl, err := d.tmplGetter.Template(cfnstack.NameForEnv(d.app.Name, d.env.Name))
+	if err != nil {
+		return "", fmt.Errorf("retrieve the deployed template for %q: %w", d.env.Name, err)
+	}
+	diffTree, err := diff.From(tmpl).ParseWithCFNIgnorer([]byte(template))
+	if err != nil {
+		return "", fmt.Errorf("parse the diff against the deployed env stack %q: %w", d.env.Name, err)
+	}
+	buf := strings.Builder{}
+	if err := diffTree.Write(&buf); err != nil {
+		return "", err
+	}
+	return buf.String(), nil
+}
+
 // AddonsTemplate returns the environment addons template.
 func (d *envDeployer) AddonsTemplate() (string, error) {
 	addons, err := d.parseAddons()
@@ -379,18 +399,10 @@ func (d *envDeployer) buildStackInput(in *DeployEnvironmentInput) (*cfnstack.Env
 	if err != nil {
 		return nil, err
 	}
-	parsedAddons, err := d.parseAddons()
-	var notFoundErr *addon.ErrAddonsNotFound
-	if err != nil && !errors.As(err, &notFoundErr) {
+	addons, err := d.buildAddonsInput(resources.Region, resources.S3Bucket, in.AddonsURL)
+	if err != nil {
 		return nil, err
 	}
-	var addons *cfnstack.Addons
-	if err == nil {
-		addons = &cfnstack.Addons{
-			S3ObjectURL: in.AddonsURL,
-			Stack:       parsedAddons,
-		}
-	}
 	return &cfnstack.EnvConfig{
 		Name: d.env.Name,
 		App: deploy.AppInformation{
@@ -413,6 +425,31 @@ func (d *envDeployer) buildStackInput(in *DeployEnvironmentInput) (*cfnstack.Env
 	}, nil
 }
 
+func (d *envDeployer) buildAddonsInput(region, bucket, uploadURL string) (*cfnstack.Addons, error) {
+	parsedAddons, err := d.parseAddons()
+	if err != nil {
+		var notFoundErr *addon.ErrAddonsNotFound
+		if errors.As(err, &notFoundErr) {
+			return nil, nil
+		}
+		return nil, err
+	}
+	if uploadURL != "" {
+		return &cfnstack.Addons{
+			S3ObjectURL: uploadURL,
+			Stack:       parsedAddons,
+		}, nil
+	}
+	tpl, err := parsedAddons.Template()
+	if err != nil {
+		return nil, fmt.Errorf("render addons template: %w", err)
+	}
+	return &cfnstack.Addons{
+		S3ObjectURL: s3.URL(region, bucket, artifactpath.EnvironmentAddons([]byte(tpl))),
+		Stack:       parsedAddons,
+	}, nil
+}
+
 // lbServiceRedirects returns true if svc's HTTP listener rule redirects. We only check
 // HTTPListenerRuleWithDomain because HTTPListenerRule doesn't ever redirect.
 func (d *envDeployer) lbServiceRedirects(ctx context.Context, svc string) (bool, error) {
