@@ -249,6 +249,74 @@ func TestEnvDeployer_UploadArtifacts(t *testing.T) {
 	}
 }
 
+func TestEnvDeployer_DeployDiff(t *testing.T) {
+	testCases := map[string]struct {
+		inTemplate string
+		setUpMocks func(m *deployDiffMocks)
+		wanted     string
+		checkErr   func(t *testing.T, gotErr error)
+	}{
+		"error getting the deployed template": {
+			setUpMocks: func(m *deployDiffMocks) {
+				m.mockDeployedTmplGetter.
+					EXPECT().Template(gomock.Eq(cfnstack.NameForEnv("mockApp", "mockEnv"))).
+					Return("", errors.New("some error"))
+			},
+			checkErr: func(t *testing.T, gotErr error) {
+				require.EqualError(t, gotErr, `retrieve the deployed template for "mockEnv": some error`)
+			},
+		},
+		"error parsing the diff against the deployed template": {
+			inTemplate: `!!!???what a weird template`,
+			setUpMocks: func(m *deployDiffMocks) {
+				m.mockDeployedTmplGetter.EXPECT().
+					Template(gomock.Eq(cfnstack.NameForEnv("mockApp", "mockEnv"))).
+					Return("wow such template", nil)
+			},
+			checkErr: func(t *testing.T, gotErr error) {
+				require.ErrorContains(t, gotErr, `parse the diff against the deployed env stack "mockEnv"`)
+			},
+		},
+		"get the correct diff": {
+			inTemplate: `peace: and love`,
+			setUpMocks: func(m *deployDiffMocks) {
+				m.mockDeployedTmplGetter.EXPECT().
+					Template(gomock.Eq(cfnstack.NameForEnv("mockApp", "mockEnv"))).
+					Return("peace: und Liebe", nil)
+			},
+			wanted: `~ peace: und Liebe -> and love
+`,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			m := &deployDiffMocks{
+				mockDeployedTmplGetter: mocks.NewMockdeployedTemplateGetter(ctrl),
+			}
+			tc.setUpMocks(m)
+			deployer := envDeployer{
+				app: &config.Application{
+					Name: "mockApp",
+				},
+				env: &config.Environment{
+					Name: "mockEnv",
+				},
+				tmplGetter: m.mockDeployedTmplGetter,
+			}
+			got, gotErr := deployer.DeployDiff(tc.inTemplate)
+			if tc.checkErr != nil {
+				tc.checkErr(t, gotErr)
+			} else {
+				require.NoError(t, gotErr)
+				require.Equal(t, tc.wanted, got)
+			}
+		})
+	}
+}
+
 func TestEnvDeployer_AddonsTemplate(t *testing.T) {
 	testCases := map[string]struct {
 		setUpMocks  func(m *envDeployerMocks)
@@ -315,43 +383,52 @@ func TestEnvDeployer_GenerateCloudFormationTemplate(t *testing.T) {
 		Name: mockAppName,
 	}
 	testCases := map[string]struct {
-		setUpMocks func(m *envDeployerMocks)
+		setUpMocks func(m *envDeployerMocks, ctrl *gomock.Controller)
 
 		wantedTemplate string
 		wantedParams   string
 		wantedError    error
 	}{
 		"fail to get app resources by region": {
-			setUpMocks: func(m *envDeployerMocks) {
+			setUpMocks: func(m *envDeployerMocks, _ *gomock.Controller) {
 				m.appCFN.EXPECT().GetAppResourcesByRegion(gomock.Any(), gomock.Any()).
 					Return(nil, errors.New("some error"))
 			},
 			wantedError: errors.New("get app resources in region us-west-2: some error"),
 		},
 		"fail to get existing parameters": {
-			setUpMocks: func(m *envDeployerMocks) {
+			setUpMocks: func(m *envDeployerMocks, _ *gomock.Controller) {
 				m.appCFN.EXPECT().GetAppResourcesByRegion(gomock.Any(), gomock.Any()).Return(&cfnstack.AppRegionalResources{
 					S3Bucket: "mockS3Bucket",
 				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					return nil, &addon.ErrAddonsNotFound{}
+				}
 				m.envDeployer.EXPECT().DeployedEnvironmentParameters(gomock.Any(), gomock.Any()).Return(nil, errors.New("some error"))
 			},
 			wantedError: errors.New("describe environment stack parameters: some error"),
 		},
 		"fail to get existing force update ID": {
-			setUpMocks: func(m *envDeployerMocks) {
+			setUpMocks: func(m *envDeployerMocks, _ *gomock.Controller) {
 				m.appCFN.EXPECT().GetAppResourcesByRegion(gomock.Any(), gomock.Any()).Return(&cfnstack.AppRegionalResources{
 					S3Bucket: "mockS3Bucket",
 				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					return nil, &addon.ErrAddonsNotFound{}
+				}
 				m.envDeployer.EXPECT().DeployedEnvironmentParameters(gomock.Any(), gomock.Any()).Return(nil, nil)
 				m.envDeployer.EXPECT().ForceUpdateOutputID(gomock.Any(), gomock.Any()).Return("", errors.New("some error"))
 			},
 			wantedError: errors.New("retrieve environment stack force update ID: some error"),
 		},
 		"fail to generate stack template": {
-			setUpMocks: func(m *envDeployerMocks) {
+			setUpMocks: func(m *envDeployerMocks, _ *gomock.Controller) {
 				m.appCFN.EXPECT().GetAppResourcesByRegion(gomock.Any(), gomock.Any()).Return(&cfnstack.AppRegionalResources{
 					S3Bucket: "mockS3Bucket",
 				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					return nil, &addon.ErrAddonsNotFound{}
+				}
 				m.envDeployer.EXPECT().DeployedEnvironmentParameters(gomock.Any(), gomock.Any()).Return(nil, nil)
 				m.envDeployer.EXPECT().ForceUpdateOutputID(gomock.Any(), gomock.Any()).Return("", nil)
 				m.stackSerializer.EXPECT().Template().Return("", errors.New("some error"))
@@ -359,10 +436,13 @@ func TestEnvDeployer_GenerateCloudFormationTemplate(t *testing.T) {
 			wantedError: errors.New("generate stack template: some error"),
 		},
 		"fail to generate stack parameters": {
-			setUpMocks: func(m *envDeployerMocks) {
+			setUpMocks: func(m *envDeployerMocks, _ *gomock.Controller) {
 				m.appCFN.EXPECT().GetAppResourcesByRegion(gomock.Any(), gomock.Any()).Return(&cfnstack.AppRegionalResources{
 					S3Bucket: "mockS3Bucket",
 				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					return nil, &addon.ErrAddonsNotFound{}
+				}
 				m.envDeployer.EXPECT().DeployedEnvironmentParameters(gomock.Any(), gomock.Any()).Return(nil, nil)
 				m.envDeployer.EXPECT().ForceUpdateOutputID(gomock.Any(), gomock.Any()).Return("", nil)
 				m.stackSerializer.EXPECT().Template().Return("", nil)
@@ -370,11 +450,57 @@ func TestEnvDeployer_GenerateCloudFormationTemplate(t *testing.T) {
 			},
 			wantedError: errors.New("generate stack template parameters: some error"),
 		},
-		"successfully return templates environment deployment": {
-			setUpMocks: func(m *envDeployerMocks) {
+		"return an error when addons cannot be parsed due to unknown reasons": {
+			setUpMocks: func(m *envDeployerMocks, _ *gomock.Controller) {
 				m.appCFN.EXPECT().GetAppResourcesByRegion(mockApp, mockEnvRegion).Return(&cfnstack.AppRegionalResources{
 					S3Bucket: "mockS3Bucket",
 				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					return nil, errors.New("some error")
+				}
+			},
+			wantedError: errors.New("some error"),
+		},
+		"return an error if the URL isn't provided and addons template cannot be retrieved": {
+			setUpMocks: func(m *envDeployerMocks, ctrl *gomock.Controller) {
+				m.appCFN.EXPECT().GetAppResourcesByRegion(mockApp, mockEnvRegion).Return(&cfnstack.AppRegionalResources{
+					S3Bucket: "mockS3Bucket",
+				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					mockStack := mocks.NewMockstackBuilder(ctrl)
+					mockStack.EXPECT().Template().Return("", errors.New("some error"))
+					return mockStack, nil
+				}
+			},
+			wantedError: errors.New("render addons template: some error"),
+		},
+		"successfully return environment template without addons": {
+			setUpMocks: func(m *envDeployerMocks, _ *gomock.Controller) {
+				m.appCFN.EXPECT().GetAppResourcesByRegion(mockApp, mockEnvRegion).Return(&cfnstack.AppRegionalResources{
+					S3Bucket: "mockS3Bucket",
+				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					return nil, &addon.ErrAddonsNotFound{}
+				}
+				m.envDeployer.EXPECT().DeployedEnvironmentParameters(mockAppName, mockEnvName).Return(nil, nil)
+				m.envDeployer.EXPECT().ForceUpdateOutputID(gomock.Any(), gomock.Any()).Return("", nil)
+				m.stackSerializer.EXPECT().Template().Return("aloo", nil)
+				m.stackSerializer.EXPECT().SerializedParameters().Return("gobi", nil)
+			},
+
+			wantedTemplate: "aloo",
+			wantedParams:   "gobi",
+		},
+		"successfully return environment template with addons": {
+			setUpMocks: func(m *envDeployerMocks, ctrl *gomock.Controller) {
+				m.appCFN.EXPECT().GetAppResourcesByRegion(mockApp, mockEnvRegion).Return(&cfnstack.AppRegionalResources{
+					S3Bucket: "mockS3Bucket",
+				}, nil)
+				m.parseAddons = func() (stackBuilder, error) {
+					mockStack := mocks.NewMockstackBuilder(ctrl)
+					mockStack.EXPECT().Template().Return("template", nil)
+					return mockStack, nil
+				}
 				m.envDeployer.EXPECT().DeployedEnvironmentParameters(mockAppName, mockEnvName).Return(nil, nil)
 				m.envDeployer.EXPECT().ForceUpdateOutputID(gomock.Any(), gomock.Any()).Return("", nil)
 				m.stackSerializer.EXPECT().Template().Return("aloo", nil)
@@ -395,7 +521,7 @@ func TestEnvDeployer_GenerateCloudFormationTemplate(t *testing.T) {
 				envDeployer:     mocks.NewMockenvironmentDeployer(ctrl),
 				stackSerializer: cfnmocks.NewMockStackConfiguration(ctrl),
 			}
-			tc.setUpMocks(m)
+			tc.setUpMocks(m, ctrl)
 			d := envDeployer{
 				app: mockApp,
 				env: &config.Environment{
@@ -407,9 +533,7 @@ func TestEnvDeployer_GenerateCloudFormationTemplate(t *testing.T) {
 				newStack: func(_ *cfnstack.EnvConfig, _ string, _ []*awscfn.Parameter) (cloudformation.StackConfiguration, error) {
 					return m.stackSerializer, nil
 				},
-				parseAddons: func() (stackBuilder, error) {
-					return nil, &addon.ErrAddonsNotFound{}
-				},
+				parseAddons: m.parseAddons,
 			}
 			actual, err := d.GenerateCloudFormationTemplate(&DeployEnvironmentInput{})
 			if tc.wantedError != nil {
