@@ -101,23 +101,23 @@ func (m *mockTopicLister) ListSNSTopics(_, _ string) ([]deploy.Topic, error) {
 }
 
 type mockWorkloadMft struct {
-	fileName      string
-	buildRequired bool
+	fileName        string
+	dockerBuildArgs map[string]*manifest.DockerBuildArgs
+	workloadName    string
+	customEnvFiles  map[string]string
 }
 
-func (m *mockWorkloadMft) EnvFile() string {
-	return m.fileName
-}
-
-func (m *mockWorkloadMft) BuildRequired() (bool, error) {
-	return m.buildRequired, nil
-}
-
-func (m *mockWorkloadMft) BuildArgs(rootDirectory string) *manifest.DockerBuildArgs {
-	return &manifest.DockerBuildArgs{
-		Dockerfile: aws.String("mockDockerfile"),
-		Context:    aws.String("mockContext"),
+func (m *mockWorkloadMft) EnvFiles() map[string]string {
+	if m.customEnvFiles != nil {
+		return m.customEnvFiles
 	}
+	return map[string]string{
+		m.workloadName: m.fileName,
+	}
+}
+
+func (m *mockWorkloadMft) BuildArgs(rootDirectory string) (map[string]*manifest.DockerBuildArgs, error) {
+	return m.dockerBuildArgs, nil
 }
 
 func (m *mockWorkloadMft) ContainerPlatform() string {
@@ -146,6 +146,10 @@ func (s *stubCloudFormationStack) SerializedParameters() (string, error) {
 	return "", nil
 }
 
+func mockEnvFilePath(path string) string {
+	return fmt.Sprintf("%s/%s/%s/%s.env", "manual", "env-files", path, "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855")
+}
+
 func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 	const (
 		mockName            = "mockWkld"
@@ -154,61 +158,166 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 		mockWorkspacePath   = "."
 		mockEnvFile         = "foo.env"
 		mockS3Bucket        = "mockBucket"
-		mockImageTag        = "mockImageTag"
 		mockAddonsS3URL     = "https://mockS3DomainName/mockPath"
 		mockBadEnvFileS3URL = "badURL"
 		mockEnvFileS3URL    = "https://stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf.s3.us-west-2.amazonaws.com/manual/1638391936/env"
+		mockEnvFileS3URL2   = "https://stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf.s3.us-west-2.amazonaws.com/manual/1638391936/envbar"
 		mockEnvFileS3ARN    = "arn:aws:s3:::stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf/manual/1638391936/env"
+		mockEnvFileS3ARN2   = "arn:aws:s3:::stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf/manual/1638391936/envbar"
 	)
+	var mockEnvFilesOutput = map[string]string{"mockWkld": mockEnvFileS3ARN}
 	mockResources := &stack.AppRegionalResources{
 		S3Bucket: mockS3Bucket,
 	}
-	mockEnvFilePath := fmt.Sprintf("%s/%s/%s/%s.env", "manual", "env-files", mockEnvFile, "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855")
 	mockAddonPath := fmt.Sprintf("%s/%s/%s/%s.yml", "manual", "addons", mockName, "1307990e6ba5ca145eb35e99182a9bec46531bc54ddf656a602c780fa0240dee")
 	mockError := errors.New("some error")
-
 	type artifactsUploader interface {
 		UploadArtifacts() (*UploadArtifactsOutput, error)
 	}
 	tests := map[string]struct {
-		inEnvFile       string
-		inBuildRequired bool
-		inRegion        string
+		inEnvFile         string
+		customEnvFiles    map[string]string
+		inRegion          string
+		inMockUserTag     string
+		inMockGitTag      string
+		inDockerBuildArgs map[string]*manifest.DockerBuildArgs
 
 		mock                func(t *testing.T, m *deployMocks)
 		mockServiceDeployer func(deployer *workloadDeployer) artifactsUploader
 		customResourcesFunc customResourcesFunc
 
 		wantAddonsURL     string
-		wantEnvFileARN    string
-		wantImageDigest   *string
+		wantEnvFileARNs   map[string]string
+		wantImages        map[string]ContainerImageIdentifier
 		wantBuildRequired bool
 		wantErr           error
 	}{
 		"error if failed to build and push image": {
-			inBuildRequired: true,
+			inMockUserTag: "v1.0",
+			inDockerBuildArgs: map[string]*manifest.DockerBuildArgs{
+				"mockWkld": {
+					Dockerfile: aws.String("mockDockerfile"),
+					Context:    aws.String("mockContext"),
+				},
+			},
 			mock: func(t *testing.T, m *deployMocks) {
 				m.mockImageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 					Dockerfile: "mockDockerfile",
 					Context:    "mockContext",
 					Platform:   "mockContainerPlatform",
-					Tags:       []string{mockImageTag},
+					Tags:       []string{"latest", "v1.0"},
+					Labels: map[string]string{
+						"com.aws.copilot.image.builder":        "copilot-cli",
+						"com.aws.copilot.image.container.name": "mockWkld",
+					},
 				}).Return("", mockError)
 			},
 			wantErr: fmt.Errorf("build and push image: some error"),
 		},
-		"build and push image successfully": {
-			inBuildRequired: true,
+		"build and push image with usertag successfully": {
+			inMockUserTag: "v1.0",
+			inMockGitTag:  "gitTag",
+			inDockerBuildArgs: map[string]*manifest.DockerBuildArgs{
+				"mockWkld": {
+					Dockerfile: aws.String("mockDockerfile"),
+					Context:    aws.String("mockContext"),
+				},
+			},
 			mock: func(t *testing.T, m *deployMocks) {
 				m.mockImageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 					Dockerfile: "mockDockerfile",
 					Context:    "mockContext",
 					Platform:   "mockContainerPlatform",
-					Tags:       []string{mockImageTag},
+					Tags:       []string{"latest", "v1.0"},
+					Labels: map[string]string{
+						"com.aws.copilot.image.builder":        "copilot-cli",
+						"com.aws.copilot.image.container.name": "mockWkld",
+					},
 				}).Return("mockDigest", nil)
 				m.mockAddons = nil
 			},
-			wantImageDigest: aws.String("mockDigest"),
+			wantImages: map[string]ContainerImageIdentifier{
+				mockName: {
+					Digest:            "mockDigest",
+					CustomTag:         "v1.0",
+					GitShortCommitTag: "gitTag",
+				},
+			},
+		},
+
+		"build and push image with gitshortcommit successfully": {
+			inMockGitTag: "gitTag",
+			inDockerBuildArgs: map[string]*manifest.DockerBuildArgs{
+				"mockWkld": {
+					Dockerfile: aws.String("mockDockerfile"),
+					Context:    aws.String("mockContext"),
+				},
+			},
+			mock: func(t *testing.T, m *deployMocks) {
+				m.mockImageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
+					Dockerfile: "mockDockerfile",
+					Context:    "mockContext",
+					Platform:   "mockContainerPlatform",
+					Tags:       []string{"latest", "gitTag"},
+					Labels: map[string]string{
+						"com.aws.copilot.image.builder":        "copilot-cli",
+						"com.aws.copilot.image.container.name": "mockWkld",
+					},
+				}).Return("mockDigest", nil)
+				m.mockAddons = nil
+			},
+			wantImages: map[string]ContainerImageIdentifier{
+				mockName: {
+					Digest:            "mockDigest",
+					GitShortCommitTag: "gitTag",
+				},
+			},
+		},
+		"build and push sidecar container images only with git tag succesfully": {
+			inDockerBuildArgs: map[string]*manifest.DockerBuildArgs{
+				"nginx": {
+					Dockerfile: aws.String("sidecarMockDockerfile"),
+					Context:    aws.String("sidecarMockContext"),
+				},
+				"logging": {
+					Dockerfile: aws.String("web/Dockerfile"),
+					Context:    aws.String("Users/bowie"),
+				},
+			},
+			inMockGitTag: "gitTag",
+			mock: func(t *testing.T, m *deployMocks) {
+				m.mockImageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
+					Dockerfile: "sidecarMockDockerfile",
+					Context:    "sidecarMockContext",
+					Platform:   "mockContainerPlatform",
+					Tags:       []string{fmt.Sprintf("nginx-%s", "latest"), fmt.Sprintf("nginx-%s", "gitTag")},
+					Labels: map[string]string{
+						"com.aws.copilot.image.builder":        "copilot-cli",
+						"com.aws.copilot.image.container.name": "nginx",
+					},
+				}).Return("sidecarMockDigest1", nil)
+				m.mockImageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
+					Dockerfile: "web/Dockerfile",
+					Context:    "Users/bowie",
+					Platform:   "mockContainerPlatform",
+					Tags:       []string{"logging-latest", fmt.Sprintf("logging-%s", "gitTag")},
+					Labels: map[string]string{
+						"com.aws.copilot.image.builder":        "copilot-cli",
+						"com.aws.copilot.image.container.name": "logging",
+					},
+				}).Return("sidecarMockDigest2", nil)
+				m.mockAddons = nil
+			},
+			wantImages: map[string]ContainerImageIdentifier{
+				"nginx": {
+					Digest:            "sidecarMockDigest1",
+					GitShortCommitTag: "gitTag",
+				},
+				"logging": {
+					Digest:            "sidecarMockDigest2",
+					GitShortCommitTag: "gitTag",
+				},
+			},
 		},
 		"should retrieve Load Balanced Web Service custom resource URLs": {
 			mock: func(t *testing.T, m *deployMocks) {
@@ -356,11 +465,50 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 			},
 			wantErr: fmt.Errorf("read env file foo.env: some error"),
 		},
+		"successfully share one env file between containers": {
+			customEnvFiles: map[string]string{"nginx": mockEnvFile, mockName: mockEnvFile},
+			inRegion:       "us-west-2",
+			mock: func(t *testing.T, m *deployMocks) {
+				m.mockFileReader.EXPECT().ReadFile(filepath.Join(mockWorkspacePath, mockEnvFile)).Return([]byte{}, nil)
+				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath(mockEnvFile), gomock.Any()).Return(mockEnvFileS3URL, nil)
+				m.mockAddons.EXPECT().Package(gomock.Any()).Return(nil)
+				m.mockAddons.EXPECT().Template().Return("", nil)
+				m.mockUploader.EXPECT().Upload(gomock.Any(), gomock.Any(), gomock.Any()).Return(mockAddonsS3URL, nil)
+			},
+			wantEnvFileARNs: map[string]string{"nginx": mockEnvFileS3ARN, mockName: mockEnvFileS3ARN},
+			wantAddonsURL:   mockAddonsS3URL,
+		},
+		"upload multiple env files": {
+			customEnvFiles: map[string]string{"nginx": mockEnvFile, mockName: "bar.env"},
+			inRegion:       "us-west-2",
+			mock: func(t *testing.T, m *deployMocks) {
+				m.mockFileReader.EXPECT().ReadFile(filepath.Join(mockWorkspacePath, mockEnvFile)).Return([]byte{}, nil)
+				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath(mockEnvFile), gomock.Any()).Return(mockEnvFileS3URL, nil)
+				m.mockFileReader.EXPECT().ReadFile(filepath.Join(mockWorkspacePath, "bar.env")).Return([]byte{}, nil)
+				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath("bar.env"), gomock.Any()).Return(mockEnvFileS3URL2, nil)
+				m.mockAddons.EXPECT().Package(gomock.Any()).Return(nil)
+				m.mockAddons.EXPECT().Template().Return("", nil)
+				m.mockUploader.EXPECT().Upload(gomock.Any(), gomock.Any(), gomock.Any()).Return(mockAddonsS3URL, nil)
+			},
+			wantEnvFileARNs: map[string]string{"nginx": mockEnvFileS3ARN, mockName: mockEnvFileS3ARN2},
+			wantAddonsURL:   mockAddonsS3URL,
+		},
+		"success with no env files present but logging sidecar exists": {
+			inRegion:       "us-west-2",
+			customEnvFiles: map[string]string{manifest.FirelensContainerName: "", mockName: ""},
+			mock: func(t *testing.T, m *deployMocks) {
+				m.mockAddons.EXPECT().Package(gomock.Any()).Return(nil)
+				m.mockAddons.EXPECT().Template().Return("", nil)
+				m.mockUploader.EXPECT().Upload(gomock.Any(), gomock.Any(), gomock.Any()).Return(mockAddonsS3URL, nil)
+			},
+			wantEnvFileARNs: nil,
+			wantAddonsURL:   mockAddonsS3URL,
+		},
 		"error if fail to put env file to s3 bucket": {
 			inEnvFile: mockEnvFile,
 			mock: func(t *testing.T, m *deployMocks) {
 				m.mockFileReader.EXPECT().ReadFile(filepath.Join(mockWorkspacePath, mockEnvFile)).Return([]byte{}, nil)
-				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath(mockEnvFile), gomock.Any()).
 					Return("", mockError)
 			},
 			wantErr: fmt.Errorf("put env file foo.env artifact to bucket mockBucket: some error"),
@@ -369,7 +517,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 			inEnvFile: mockEnvFile,
 			mock: func(t *testing.T, m *deployMocks) {
 				m.mockFileReader.EXPECT().ReadFile(filepath.Join(mockWorkspacePath, mockEnvFile)).Return([]byte{}, nil)
-				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath(mockEnvFile), gomock.Any()).
 					Return(mockBadEnvFileS3URL, nil)
 
 			},
@@ -380,7 +528,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 			inRegion:  "sun-south-0",
 			mock: func(t *testing.T, m *deployMocks) {
 				m.mockFileReader.EXPECT().ReadFile(filepath.Join(mockWorkspacePath, mockEnvFile)).Return([]byte{}, nil)
-				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath(mockEnvFile), gomock.Any()).
 					Return(mockEnvFileS3URL, nil)
 			},
 			wantErr: fmt.Errorf("find the partition for region sun-south-0"),
@@ -390,7 +538,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 			inRegion:  "us-west-2",
 			mock: func(t *testing.T, m *deployMocks) {
 				m.mockFileReader.EXPECT().ReadFile(filepath.Join(mockWorkspacePath, mockEnvFile)).Return([]byte{}, nil)
-				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+				m.mockUploader.EXPECT().Upload(mockS3Bucket, mockEnvFilePath(mockEnvFile), gomock.Any()).
 					Return(mockEnvFileS3URL, nil)
 				m.mockAddons.EXPECT().Package(gomock.Any()).Return(nil)
 				m.mockAddons.EXPECT().Template().Return("some data", nil)
@@ -398,8 +546,8 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					Return(mockAddonsS3URL, nil)
 			},
 
-			wantAddonsURL:  mockAddonsS3URL,
-			wantEnvFileARN: mockEnvFileS3ARN,
+			wantAddonsURL:   mockAddonsS3URL,
+			wantEnvFileARNs: mockEnvFilesOutput,
 		},
 		"should return error if fail to upload to S3 bucket": {
 			inRegion: "us-west-2",
@@ -461,12 +609,17 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				app: &config.Application{
 					Name: mockAppName,
 				},
-				resources:     mockResources,
-				imageTag:      mockImageTag,
+				resources: mockResources,
+				image: ContainerImageIdentifier{
+					CustomTag:         tc.inMockUserTag,
+					GitShortCommitTag: tc.inMockGitTag,
+				},
 				workspacePath: mockWorkspacePath,
 				mft: &mockWorkloadMft{
-					fileName:      tc.inEnvFile,
-					buildRequired: tc.inBuildRequired,
+					workloadName:    mockName,
+					fileName:        tc.inEnvFile,
+					customEnvFiles:  tc.customEnvFiles,
+					dockerBuildArgs: tc.inDockerBuildArgs,
 				},
 				fs:                 m.mockFileReader,
 				s3Client:           m.mockUploader,
@@ -495,8 +648,8 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 			} else {
 				require.NoError(t, gotErr)
 				require.Equal(t, tc.wantAddonsURL, got.AddonsURL)
-				require.Equal(t, tc.wantEnvFileARN, got.EnvFileARN)
-				require.Equal(t, tc.wantImageDigest, got.ImageDigest)
+				require.Equal(t, tc.wantEnvFileARNs, got.EnvFileARNs)
+				require.Equal(t, tc.wantImages, got.ImageDigests)
 			}
 		})
 	}
@@ -580,7 +733,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf("cannot deploy service mockWkld without http.alias to environment mockEnv with certificate imported"),
+			wantErr: fmt.Errorf(`validate ALB runtime configuration for "http": cannot deploy service mockWkld without "alias" to environment mockEnv with certificate imported`),
 		},
 		"fail if http redirect to https configured without custom domain": {
 			inRedirectToHTTPS: aws.Bool(true),
@@ -598,7 +751,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf(`cannot configure http to https redirect without having a domain associated with the app "mockApp" or importing any certificates in env "mockEnv"`),
+			wantErr: fmt.Errorf(`validate ALB runtime configuration for "http": cannot configure http to https redirect without having a domain associated with the app "mockApp" or importing any certificates in env "mockEnv"`),
 		},
 		"cannot specify alias hosted zone when no certificates are imported in the env": {
 			inEnvironment: &config.Environment{
@@ -628,7 +781,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf("cannot specify alias hosted zones [mockHostedZone1 mockHostedZone2] when no certificates are imported in environment \"mockEnv\""),
+			wantErr: fmt.Errorf("validate ALB runtime configuration for \"http\": cannot specify alias hosted zones [mockHostedZone1 mockHostedZone2] when no certificates are imported in environment \"mockEnv\""),
 		},
 		"cannot specify alias hosted zone when cdn is enabled": {
 			inEnvironment: &config.Environment{
@@ -660,7 +813,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf("cannot specify alias hosted zones when cdn is enabled in environment \"mockEnv\""),
+			wantErr: fmt.Errorf("validate ALB runtime configuration for \"http\": cannot specify alias hosted zones when cdn is enabled in environment \"mockEnv\""),
 		},
 		"fail to validate certificate aliases": {
 			inEnvironment: &config.Environment{
@@ -683,7 +836,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(mockError)
 			},
-			wantErr: fmt.Errorf("validate aliases against the imported public ALB certificate for env mockEnv: some error"),
+			wantErr: fmt.Errorf("validate ALB runtime configuration for \"http\": validate aliases against the imported public ALB certificate for env mockEnv: some error"),
 		},
 		"fail to validate cdn certificate aliases": {
 			inEnvironment: &config.Environment{
@@ -708,11 +861,13 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(nil)
 				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, []string{mockCDNCertARN}).Return(mockError)
 			},
-			wantErr: fmt.Errorf("validate aliases against the imported CDN certificate for env mockEnv: some error"),
+			wantErr: fmt.Errorf("validate ALB runtime configuration for \"http\": validate aliases against the imported CDN certificate for env mockEnv: some error"),
 		},
 		"fail to get public CIDR blocks": {
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port: aws.String("443/tcp"),
+				Listener: manifest.NetworkLoadBalancerListener{
+					Port: aws.String("443/tcp"),
+				},
 			},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -741,11 +896,13 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: errors.New("cannot specify http.alias when application is not associated with a domain and env mockEnv doesn't import one or more certificates"),
+			wantErr: errors.New(`validate ALB runtime configuration for "http": cannot specify "alias" when application is not associated with a domain and env mockEnv doesn't import one or more certificates`),
 		},
 		"nlb alias used while app is not associated with a domain": {
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port:    aws.String("80"),
+				Listener: manifest.NetworkLoadBalancerListener{
+					Port: aws.String("80"),
+				},
 				Aliases: manifest.Alias{AdvancedAliases: mockAlias},
 			},
 			inEnvironment: &config.Environment{
@@ -764,7 +921,9 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		"nlb alias used while env has imported certs": {
 			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port:    aws.String("80"),
+				Listener: manifest.NetworkLoadBalancerListener{
+					Port: aws.String("80"),
+				},
 				Aliases: manifest.Alias{AdvancedAliases: mockAlias},
 			},
 			inEnvironment: &config.Environment{
@@ -782,7 +941,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			mock: func(m *deployMocks) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
-				m.mockValidator.EXPECT().ValidateCertAliases([]string{"mockAlias"}, mockCertARNs).Return(nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"mockAlias"}, mockCertARNs).Return(nil).Times(2)
 			},
 			wantErr: errors.New("cannot specify nlb.alias when env mockEnv imports one or more certificates"),
 		},
@@ -801,7 +960,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf("get version for app %s: %w", mockAppName, mockError),
+			wantErr: fmt.Errorf("validate ALB runtime configuration for \"http\": get version for app %s: %w", mockAppName, mockError),
 		},
 		"out of date app version": {
 			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
@@ -818,7 +977,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v.0.99.0", nil)
 			},
-			wantErr: fmt.Errorf("alias is not compatible with application versions below v1.0.0"),
+			wantErr: fmt.Errorf("validate ALB runtime configuration for \"http\": alias is not compatible with application versions below v1.0.0"),
 		},
 		"fail to enable https alias because of incompatible app version": {
 			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
@@ -835,11 +994,13 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf("alias is not compatible with application versions below %s", deploy.AliasLeastAppTemplateVersion),
+			wantErr: fmt.Errorf("validate ALB runtime configuration for \"http\": alias is not compatible with application versions below %s", deploy.AliasLeastAppTemplateVersion),
 		},
 		"fail to enable nlb alias because of incompatible app version": {
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port:    aws.String("80"),
+				Listener: manifest.NetworkLoadBalancerListener{
+					Port: aws.String("80"),
+				},
 				Aliases: manifest.Alias{AdvancedAliases: mockAlias},
 			},
 			inEnvironment: &config.Environment{
@@ -874,11 +1035,13 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf(`alias "v1.v2.mockDomain" is not supported in hosted zones managed by Copilot`),
+			wantErr: fmt.Errorf(`validate ALB runtime configuration for "http": validate 'alias': alias "v1.v2.mockDomain" is not supported in hosted zones managed by Copilot`),
 		},
 		"fail to enable nlb alias because of invalid alias": {
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port: aws.String("80"),
+				Listener: manifest.NetworkLoadBalancerListener{
+					Port: aws.String("80"),
+				},
 				Aliases: manifest.Alias{AdvancedAliases: []manifest.AdvancedAlias{
 					{Alias: aws.String("v1.v2.mockDomain")},
 				}},
@@ -896,7 +1059,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
 			},
-			wantErr: fmt.Errorf(`alias "v1.v2.mockDomain" is not supported in hosted zones managed by Copilot`),
+			wantErr: fmt.Errorf(`validate 'nlb.alias': alias "v1.v2.mockDomain" is not supported in hosted zones managed by Copilot`),
 		},
 		"error if fail to deploy service": {
 			inEnvironment: &config.Environment{
@@ -1048,7 +1211,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			mock: func(m *deployMocks) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
-				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(nil).Times(2)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
 			},
 		},
@@ -1072,7 +1235,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			mock: func(m *deployMocks) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
-				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(nil).Times(2)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
 			},
 		},
@@ -1095,7 +1258,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			mock: func(m *deployMocks) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
-				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, []string{mockCDNCertARN}).Return(nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, []string{mockCDNCertARN}).Return(nil).Times(2)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
 			},
 		},
@@ -1123,7 +1286,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			mock: func(m *deployMocks) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
-				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil).Times(2)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
 			},
 		},
@@ -1213,11 +1376,20 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 								Port: aws.Uint16(80),
 							},
 						},
-						RoutingRule: manifest.RoutingRuleConfigOrBool{
-							RoutingRuleConfiguration: manifest.RoutingRuleConfiguration{
-								Path:            aws.String("/"),
-								Alias:           tc.inAliases,
-								RedirectToHTTPS: tc.inRedirectToHTTPS,
+						HTTPOrBool: manifest.HTTPOrBool{
+							HTTP: manifest.HTTP{
+								Main: manifest.RoutingRule{
+									Path:            aws.String("/"),
+									Alias:           tc.inAliases,
+									RedirectToHTTPS: tc.inRedirectToHTTPS,
+								},
+								AdditionalRoutingRules: []manifest.RoutingRule{
+									{
+										Path:            aws.String("/admin"),
+										Alias:           tc.inAliases,
+										RedirectToHTTPS: tc.inRedirectToHTTPS,
+									},
+								},
 							},
 						},
 						NLBConfig: tc.inNLB,
@@ -1243,3 +1415,100 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		})
 	}
 }
+
+func TestUploadArtifacts(t *testing.T) {
+	d := &workloadDeployer{}
+	errFunc := func(out *UploadArtifactsOutput) error {
+		return errors.New("test error")
+	}
+	noErrFunc := func(out *UploadArtifactsOutput) error {
+		out.AddonsURL = "an addons url"
+		return nil
+	}
+
+	out, err := d.uploadArtifacts(noErrFunc, errFunc)
+	require.EqualError(t, err, "test error")
+	require.Nil(t, out)
+
+	out, err = d.uploadArtifacts(errFunc, noErrFunc)
+	require.EqualError(t, err, "test error")
+	require.Nil(t, out)
+
+	out, err = d.uploadArtifacts(noErrFunc)
+	require.NoError(t, err)
+	require.Equal(t, &UploadArtifactsOutput{AddonsURL: "an addons url"}, out)
+
+}
+
+type deployDiffMocks struct {
+	mockDeployedTmplGetter *mocks.MockdeployedTemplateGetter
+}
+
+func TestWorkloadDeployer_DeployDiff(t *testing.T) {
+	testCases := map[string]struct {
+		inTemplate string
+		setUpMocks func(m *deployDiffMocks)
+		wanted     string
+		checkErr   func(t *testing.T, gotErr error)
+	}{
+		"error getting the deployed template": {
+			setUpMocks: func(m *deployDiffMocks) {
+				m.mockDeployedTmplGetter.
+					EXPECT().Template(gomock.Eq(stack.NameForWorkload("mockApp", "mockEnv", "mockSvc"))).
+					Return("", errors.New("some error"))
+			},
+			checkErr: func(t *testing.T, gotErr error) {
+				require.EqualError(t, gotErr, `retrieve the deployed template for "mockSvc": some error`)
+			},
+		},
+		"error parsing the diff against the deployed template": {
+			inTemplate: `!!!???what a weird template`,
+			setUpMocks: func(m *deployDiffMocks) {
+				m.mockDeployedTmplGetter.EXPECT().
+					Template(gomock.Eq(stack.NameForWorkload("mockApp", "mockEnv", "mockSvc"))).
+					Return("wow such template", nil)
+			},
+			checkErr: func(t *testing.T, gotErr error) {
+				require.ErrorContains(t, gotErr, `parse the diff against the deployed "mockSvc" in environment "mockEnv"`)
+			},
+		},
+		"get the correct diff": {
+			inTemplate: `peace: and love`,
+			setUpMocks: func(m *deployDiffMocks) {
+				m.mockDeployedTmplGetter.EXPECT().
+					Template(gomock.Eq(stack.NameForWorkload("mockApp", "mockEnv", "mockSvc"))).
+					Return("peace: und Liebe", nil)
+			},
+			wanted: `~ peace: und Liebe -> and love
+`,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			m := &deployDiffMocks{
+				mockDeployedTmplGetter: mocks.NewMockdeployedTemplateGetter(ctrl),
+			}
+			tc.setUpMocks(m)
+			deployer := workloadDeployer{
+				name: "mockSvc",
+				app: &config.Application{
+					Name: "mockApp",
+				},
+				env: &config.Environment{
+					Name: "mockEnv",
+				},
+				tmplGetter: m.mockDeployedTmplGetter,
+			}
+			got, gotErr := deployer.DeployDiff(tc.inTemplate)
+			if tc.checkErr != nil {
+				tc.checkErr(t, gotErr)
+			} else {
+				require.NoError(t, gotErr)
+				require.Equal(t, tc.wanted, got)
+			}
+		})
+	}
+}
