@@ -39,6 +39,7 @@ const (
 	stackOutputDirFlag    = "output-dir"
 	uploadAssetsFlag      = "upload-assets"
 	deployFlag            = "deploy"
+	diffFlag              = "diff"
 
 	// Flags for operational commands.
 	limitFlag                   = "limit"
@@ -128,6 +129,11 @@ const (
 	overwriteFlag     = "overwrite"
 	inputFilePathFlag = "cli-input-yaml"
 
+	// Flags for overriding templates.
+	iacToolFlag       = "tool"
+	cdkLanguageFlag   = "cdk-language"
+	skipResourcesFlag = "skip-resources"
+
 	// Other.
 	svcPortFlag             = "port"
 	noSubscriptionFlag      = "no-subscribe"
@@ -219,6 +225,13 @@ Mutually exclusive with the --%s flag.`, inputFilePathFlag)
 	secretInputFilePathFlagDescription = fmt.Sprintf(`Optional. A YAML file in which the secret values are specified.
 Mutually exclusive with the -%s ,--%s and --%s flags.`, nameFlagShort, nameFlag, valuesFlag)
 
+	iacToolFlagDescription = fmt.Sprintf(`Infrastructure as Code tool to override a template.
+Must be one of: %s.`, strings.Join(applyAll(validIaCTools, strconv.Quote), ", "))
+	cdkLanguageFlagDescription = `Optional. The Cloud Development Kit language.`
+	overrideEnvFlagDescription = `Optional. Name of the environment to use when retrieving resources in a template.
+Defaults to a random environment.`
+	skipResourcesFlagDescription = `Optional. Skip asking for which resources to override and generate empty IaC extension files.`
+
 	repoURLFlagDescription = fmt.Sprintf(`The repository URL to trigger your pipeline.
 Supported providers are: %s.`, strings.Join(manifest.PipelineProviders, ", "))
 
@@ -237,6 +250,7 @@ const (
 	yesFlagDescription          = "Skips confirmation prompt."
 	resourceTagsFlagDescription = `Optional. Labels with a key and value separated by commas.
 Allows you to categorize resources.`
+	diffFlagDescription = "Compares the generated CloudFormation template to the deployed stack."
 
 	// Deployment.
 	deployTestFlagDescription = `Deploy your service or job to a "test" environment.`
