@@ -13,6 +13,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/aws/iam"
 	"github.com/aws/copilot-cli/internal/pkg/describe"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
@@ -156,6 +157,7 @@ func newInitOpts(vars initVars) (*initOpts, error) {
 		store:           configStore,
 		sessionProvider: sessProvider,
 		identity:        id,
+		fs:              fs,
 		newInterpolator: newManifestInterpolator,
 	}
 	deploySvcCmd := &deploySvcOpts{
@@ -244,7 +246,7 @@ func newInitOpts(vars initVars) (*initOpts, error) {
 				return err
 			}
 			switch t := wkldType; {
-			case t == manifest.ScheduledJobType:
+			case manifestinfo.IsTypeAJob(t):
 				jobVars := initJobVars{
 					initWkldVars: wkldVars,
 					schedule:     vars.schedule,
@@ -280,7 +282,7 @@ func newInitOpts(vars initVars) (*initOpts, error) {
 				o.initWlCmd = &opts
 				o.schedule = &opts.schedule // Surfaced via pointer for logging
 				o.initWkldVars = &opts.initWkldVars
-			case manifest.IsTypeAService(t):
+			case manifestinfo.IsTypeAService(t):
 				svcVars := initSvcVars{
 					initWkldVars: wkldVars,
 					port:         vars.port,
@@ -365,7 +367,7 @@ containerized services that operate together.`))
 }
 
 func (o *initOpts) logWorkloadTypeAck() {
-	if o.initWkldVars.wkldType == manifest.ScheduledJobType {
+	if manifestinfo.IsTypeAJob(o.initWkldVars.wkldType) {
 		log.Infof("Ok great, we'll set up a %s named %s in application %s running on the schedule %s.\n",
 			color.HighlightUserInput(o.initWkldVars.wkldType), color.HighlightUserInput(o.initWkldVars.name), color.HighlightUserInput(o.initWkldVars.appName), color.HighlightUserInput(*o.schedule))
 		return
@@ -378,7 +380,7 @@ func (o *initOpts) logWorkloadTypeAck() {
 }
 
 func (o *initOpts) deploy() error {
-	if o.initWkldVars.wkldType == manifest.ScheduledJobType {
+	if manifestinfo.IsTypeAJob(o.initWkldVars.wkldType) {
 		return o.deployJob()
 	}
 	return o.deploySvc()
