@@ -34,6 +34,7 @@ type packageJobVars struct {
 	tag          string
 	outputDir    string
 	uploadAssets bool
+	showDiff     bool
 }
 
 type packageJobOpts struct {
@@ -79,7 +80,7 @@ func newPackageJobOpts(vars packageJobVars) (*packageJobOpts, error) {
 				name:         o.name,
 				envName:      o.envName,
 				appName:      o.appName,
-				tag:          imageTagFromGit(o.runner, o.tag),
+				tag:          o.tag,
 				outputDir:    o.outputDir,
 				uploadAssets: o.uploadAssets,
 			},
@@ -94,6 +95,7 @@ func newPackageJobOpts(vars packageJobVars) (*packageJobOpts, error) {
 			fs:                fs,
 			sessProvider:      sessProvider,
 			newStackGenerator: newWorkloadStackGenerator,
+			gitShortCommit:    imageTagFromGit(o.runner),
 		}
 	}
 	return opts, nil
@@ -200,5 +202,9 @@ func buildJobPackageCmd() *cobra.Command {
 	cmd.Flags().StringVar(&vars.tag, imageTagFlag, "", imageTagFlagDescription)
 	cmd.Flags().StringVar(&vars.outputDir, stackOutputDirFlag, "", stackOutputDirFlagDescription)
 	cmd.Flags().BoolVar(&vars.uploadAssets, uploadAssetsFlag, false, uploadAssetsFlagDescription)
+	cmd.Flags().BoolVar(&vars.showDiff, diffFlag, false, diffFlagDescription)
+
+	cmd.MarkFlagsMutuallyExclusive(diffFlag, stackOutputDirFlag)
+	cmd.MarkFlagsMutuallyExclusive(diffFlag, uploadAssetsFlag)
 	return cmd
 }
