@@ -4,7 +4,10 @@
 package cli
 
 import (
+	"errors"
 	"fmt"
+	"io"
+	"os"
 	"path/filepath"
 	"strings"
 
@@ -42,6 +45,7 @@ type deployWkldVars struct {
 	resourceTags    map[string]string
 	forceNewUpdate  bool // NOTE: this variable is not applicable for a job workload currently.
 	disableRollback bool
+	showDiff        bool
 
 	// To facilitate unit tests.
 	clientConfigured bool
@@ -58,10 +62,12 @@ type deploySvcOpts struct {
 	sessProvider         *sessions.Provider
 	newSvcDeployer       func() (workloadDeployer, error)
 	envFeaturesDescriber versionCompatibilityChecker
+	diffWriter           io.Writer
 
-	spinner progress
-	sel     wsSelector
-	prompt  prompter
+	spinner        progress
+	sel            wsSelector
+	prompt         prompter
+	gitShortCommit string
 
 	// cached variables
 	targetApp         *config.Application
@@ -71,6 +77,7 @@ type deploySvcOpts struct {
 	appliedDynamicMft manifest.DynamicWorkload
 	rootUserARN       string
 	deployRecs        clideploy.ActionRecommender
+	noDeploy          bool
 }
 
 func newSvcDeployOpts(vars deployWkldVars) (*deploySvcOpts, error) {
@@ -100,6 +107,7 @@ func newSvcDeployOpts(vars deployWkldVars) (*deploySvcOpts, error) {
 		newInterpolator: newManifestInterpolator,
 		cmd:             exec.NewCmd(),
 		sessProvider:    sessProvider,
+		diffWriter:      os.Stdout,
 	}
 	opts.newSvcDeployer = func() (workloadDeployer, error) {
 		// NOTE: Defined as a struct member to facilitate unit testing.
@@ -125,11 +133,14 @@ func newSvcDeployer(o *deploySvcOpts) (workloadDeployer, error) {
 	content := o.appliedDynamicMft.Manifest()
 	var deployer workloadDeployer
 	in := clideploy.WorkloadDeployerInput{
-		SessionProvider:  o.sessProvider,
-		Name:             o.name,
-		App:              targetApp,
-		Env:              o.targetEnv,
-		ImageTag:         o.imageTag,
+		SessionProvider: o.sessProvider,
+		Name:            o.name,
+		App:             targetApp,
+		Env:             o.targetEnv,
+		Image: clideploy.ContainerImageIdentifier{
+			CustomTag:         o.imageTag,
+			GitShortCommitTag: o.gitShortCommit,
+		},
 		Mft:              content,
 		RawMft:           raw,
 		EnvVersionGetter: o.envFeaturesDescriber,
@@ -144,6 +155,8 @@ func newSvcDeployer(o *deploySvcOpts) (workloadDeployer, error) {
 		deployer, err = clideploy.NewRDWSDeployer(&in)
 	case *manifest.WorkerService:
 		deployer, err = clideploy.NewWorkerSvcDeployer(&in)
+	case *manifest.StaticSite:
+		deployer, err = clideploy.NewStaticSiteDeployer(&in)
 	default:
 		return nil, fmt.Errorf("unknown manifest type %T while creating the CloudFormation stack", t)
 	}
@@ -227,10 +240,39 @@ func (o *deploySvcOpts) Execute() error {
 	if err != nil {
 		return err
 	}
+	if o.showDiff {
+		output, err := deployer.GenerateCloudFormationTemplate(&clideploy.GenerateCloudFormationTemplateInput{
+			StackRuntimeConfiguration: clideploy.StackRuntimeConfiguration{
+				RootUserARN:        o.rootUserARN,
+				Tags:               targetApp.Tags,
+				EnvFileARNs:        uploadOut.EnvFileARNs,
+				ImageDigests:       uploadOut.ImageDigests,
+				AddonsURL:          uploadOut.AddonsURL,
+				CustomResourceURLs: uploadOut.CustomResourceURLs,
+			},
+		})
+		if err != nil {
+			return fmt.Errorf("generate the template for workload %q against environment %q: %w", o.name, o.envName, err)
+		}
+		if err := diff(deployer, output.Template, o.diffWriter); err != nil {
+			var errHasDiff *errHasDiff
+			if !errors.As(err, &errHasDiff) {
+				return err
+			}
+		}
+		contd, err := o.prompt.Confirm(continueDeploymentPrompt, "")
+		if err != nil {
+			return fmt.Errorf("ask whether to continue with the deployment: %w", err)
+		}
+		if !contd {
+			o.noDeploy = true
+			return nil
+		}
+	}
 	deployRecs, err := deployer.DeployWorkload(&clideploy.DeployWorkloadInput{
 		StackRuntimeConfiguration: clideploy.StackRuntimeConfiguration{
-			ImageDigest:        uploadOut.ImageDigest,
-			EnvFileARN:         uploadOut.EnvFileARN,
+			ImageDigests:       uploadOut.ImageDigests,
+			EnvFileARNs:        uploadOut.EnvFileARNs,
 			AddonsURL:          uploadOut.AddonsURL,
 			RootUserARN:        o.rootUserARN,
 			Tags:               tags.Merge(targetApp.Tags, o.resourceTags),
@@ -243,7 +285,7 @@ func (o *deploySvcOpts) Execute() error {
 	})
 	if err != nil {
 		if o.disableRollback {
-			stackName := stack.NameForService(o.targetApp.Name, o.targetEnv.Name, o.name)
+			stackName := stack.NameForWorkload(o.targetApp.Name, o.targetEnv.Name, o.name)
 			rollbackCmd := fmt.Sprintf("aws cloudformation rollback-stack --stack-name %s --role-arn %s", stackName, o.targetEnv.ExecutionRoleARN)
 			log.Infof(`It seems like you have disabled automatic stack rollback for this deployment. To debug, you can:
 * Run %s to inspect the service log.
@@ -262,15 +304,16 @@ After fixing the deployment, you can:
 
 // RecommendActions returns follow-up actions the user can take after successfully executing the command.
 func (o *deploySvcOpts) RecommendActions() error {
+	if o.noDeploy {
+		return nil
+	}
 	var recommendations []string
 	uriRecs, err := o.uriRecommendedActions()
 	if err != nil {
 		return err
 	}
 	recommendations = append(recommendations, uriRecs...)
-	if o.deployRecs != nil {
-		recommendations = append(recommendations, o.deployRecs.RecommendedActions()...)
-	}
+	recommendations = append(recommendations, o.deployRecs.RecommendedActions()...)
 	recommendations = append(recommendations, o.publishRecommendedActions()...)
 	logRecommendedActions(recommendations)
 	return nil
@@ -323,7 +366,7 @@ func (o *deploySvcOpts) validateOrAskEnvName() error {
 }
 
 func (o *deploySvcOpts) configureClients() error {
-	o.imageTag = imageTagFromGit(o.cmd, o.imageTag) // Best effort assign git tag.
+	o.gitShortCommit = imageTagFromGit(o.cmd) // Best effort assign git tag.
 	env, err := o.store.GetEnvironment(o.appName, o.envName)
 	if err != nil {
 		return fmt.Errorf("get environment %s configuration: %w", o.envName, err)
@@ -543,6 +586,32 @@ func (e *errFeatureIncompatibleWithEnvironment) RecommendActions() string {
 
 }
 
+type errHasDiff struct{}
+
+func (e *errHasDiff) Error() string {
+	return "diff detected"
+}
+
+// ExitCode returns 1 for a non-empty diff.
+func (e *errHasDiff) ExitCode() int {
+	return 1
+}
+
+func diff(differ templateDiffer, tmpl string, writer io.Writer) error {
+	if out, err := differ.DeployDiff(tmpl); err != nil {
+		return err
+	} else if out != "" {
+		if _, err := writer.Write([]byte(out)); err != nil {
+			return err
+		}
+		return &errHasDiff{}
+	}
+	if _, err := writer.Write([]byte("No changes.\n")); err != nil {
+		return err
+	}
+	return nil
+}
+
 // buildSvcDeployCmd builds the `svc deploy` subcommand.
 func buildSvcDeployCmd() *cobra.Command {
 	vars := deployWkldVars{}
@@ -570,6 +639,6 @@ func buildSvcDeployCmd() *cobra.Command {
 	cmd.Flags().StringToStringVar(&vars.resourceTags, resourceTagsFlag, nil, resourceTagsFlagDescription)
 	cmd.Flags().BoolVar(&vars.forceNewUpdate, forceFlag, false, forceFlagDescription)
 	cmd.Flags().BoolVar(&vars.disableRollback, noRollbackFlag, false, noRollbackFlagDescription)
-
+	cmd.Flags().BoolVar(&vars.showDiff, diffFlag, false, diffFlagDescription)
 	return cmd
 }
