@@ -4,6 +4,7 @@
 package cli
 
 import (
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -40,6 +41,7 @@ type packageSvcVars struct {
 	tag          string
 	outputDir    string
 	uploadAssets bool
+	showDiff     bool
 
 	// To facilitate unit tests.
 	clientConfigured bool
@@ -55,6 +57,7 @@ type packageSvcOpts struct {
 	templateWriter       io.WriteCloser
 	paramsWriter         io.WriteCloser
 	addonsWriter         io.WriteCloser
+	diffWriter           io.Writer
 	runner               execRunner
 	sessProvider         *sessions.Provider
 	sel                  wsSelector
@@ -62,6 +65,7 @@ type packageSvcOpts struct {
 	newInterpolator      func(app, env string) interpolator
 	newStackGenerator    func(*packageSvcOpts) (workloadStackGenerator, error)
 	envFeaturesDescriber versionCompatibilityChecker
+	gitShortCommit       string
 
 	// cached variables
 	targetApp         *config.Application
@@ -97,6 +101,7 @@ func newPackageSvcOpts(vars packageSvcVars) (*packageSvcOpts, error) {
 		templateWriter:    os.Stdout,
 		paramsWriter:      discardFile{},
 		addonsWriter:      discardFile{},
+		diffWriter:        os.Stdout,
 		newInterpolator:   newManifestInterpolator,
 		sessProvider:      sessProvider,
 		newStackGenerator: newWorkloadStackGenerator,
@@ -125,11 +130,14 @@ func newWorkloadStackGenerator(o *packageSvcOpts) (workloadStackGenerator, error
 	content := o.appliedDynamicMft.Manifest()
 	var deployer workloadStackGenerator
 	in := clideploy.WorkloadDeployerInput{
-		SessionProvider:  o.sessProvider,
-		Name:             o.name,
-		App:              targetApp,
-		Env:              targetEnv,
-		ImageTag:         o.tag,
+		SessionProvider: o.sessProvider,
+		Name:            o.name,
+		App:             targetApp,
+		Env:             targetEnv,
+		Image: clideploy.ContainerImageIdentifier{
+			CustomTag:         o.tag,
+			GitShortCommitTag: o.gitShortCommit,
+		},
 		Mft:              content,
 		RawMft:           raw,
 		EnvVersionGetter: o.envFeaturesDescriber,
@@ -146,6 +154,8 @@ func newWorkloadStackGenerator(o *packageSvcOpts) (workloadStackGenerator, error
 		deployer, err = clideploy.NewWorkerSvcDeployer(&in)
 	case *manifest.ScheduledJob:
 		deployer, err = clideploy.NewJobDeployer(&in)
+	case *manifest.StaticSite:
+		deployer, err = clideploy.NewStaticSiteDeployer(&in)
 	default:
 		return nil, fmt.Errorf("unknown manifest type %T while creating the CloudFormation stack", t)
 	}
@@ -203,6 +213,17 @@ func (o *packageSvcOpts) Execute() error {
 	if err != nil {
 		return err
 	}
+	if o.showDiff {
+		if err := diff(gen, stack.template, o.diffWriter); err != nil {
+			var errHasDiff *errHasDiff
+			if !errors.As(err, &errHasDiff) {
+				return err
+			}
+			return &errDiffNotAvailable{
+				parentErr: err,
+			}
+		}
+	}
 	if err := o.writeAndClose(o.templateWriter, stack.template); err != nil {
 		return err
 	}
@@ -260,7 +281,7 @@ func (o *packageSvcOpts) validateOrAskEnvName() error {
 }
 
 func (o *packageSvcOpts) configureClients() error {
-	o.tag = imageTagFromGit(o.runner, o.tag) // Best effort assign git tag.
+	o.gitShortCommit = imageTagFromGit(o.runner) // Best effort assign git tag.
 	// client to retrieve an application's resources created with CloudFormation.
 	defaultSess, err := o.sessProvider.Default()
 	if err != nil {
@@ -337,8 +358,8 @@ func (o *packageSvcOpts) getWorkloadStack(generator workloadStackGenerator) (*cf
 		StackRuntimeConfiguration: clideploy.StackRuntimeConfiguration{
 			RootUserARN:        o.rootUserARN,
 			Tags:               targetApp.Tags,
-			ImageDigest:        uploadOut.ImageDigest,
-			EnvFileARN:         uploadOut.EnvFileARN,
+			EnvFileARNs:        uploadOut.EnvFileARNs,
+			ImageDigests:       uploadOut.ImageDigests,
 			AddonsURL:          uploadOut.AddonsURL,
 			CustomResourceURLs: uploadOut.CustomResourceURLs,
 		},
@@ -424,6 +445,24 @@ func (o *packageSvcOpts) RecommendActions() error {
 	return nil
 }
 
+type errDiffNotAvailable struct {
+	parentErr error
+}
+
+// Unwrap returns the parent error that is wrapped inside errDiffNotAvailable.
+func (e *errDiffNotAvailable) Unwrap() error {
+	return e.parentErr
+}
+
+func (e *errDiffNotAvailable) Error() string {
+	return e.parentErr.Error()
+}
+
+// ExitCode returns 2 when a diff is unavailable due to a parent error.
+func (e *errDiffNotAvailable) ExitCode() int {
+	return 2
+}
+
 func contains(s string, items []string) bool {
 	for _, item := range items {
 		if s == item {
@@ -464,5 +503,9 @@ func buildSvcPackageCmd() *cobra.Command {
 	cmd.Flags().StringVar(&vars.tag, imageTagFlag, "", imageTagFlagDescription)
 	cmd.Flags().StringVar(&vars.outputDir, stackOutputDirFlag, "", stackOutputDirFlagDescription)
 	cmd.Flags().BoolVar(&vars.uploadAssets, uploadAssetsFlag, false, uploadAssetsFlagDescription)
+	cmd.Flags().BoolVar(&vars.showDiff, diffFlag, false, diffFlagDescription)
+
+	cmd.MarkFlagsMutuallyExclusive(diffFlag, stackOutputDirFlag)
+	cmd.MarkFlagsMutuallyExclusive(diffFlag, uploadAssetsFlag)
 	return cmd
 }
