@@ -5,10 +5,10 @@ package cli
 
 import (
 	"bytes"
+	"errors"
 	"io"
 	"testing"
 
-	"github.com/aws/aws-sdk-go/aws"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
 
@@ -18,10 +18,6 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 )
 
-func TestPackageSvcOpts_Validate(t *testing.T) {
-	// NOTE: no optional flag needs to be validated for this command.
-}
-
 type svcPackageAskMock struct {
 	store *mocks.Mockstore
 	sel   *mocks.MockwsSelector
@@ -186,8 +182,58 @@ count: 1`
 		wantedStack  string
 		wantedParams string
 		wantedAddons string
+		wantedDiff   string
 		wantedErr    error
 	}{
+		"fail to get the diff": {
+			inVars: packageSvcVars{
+				name:             "api",
+				clientConfigured: true,
+				showDiff:         true,
+			},
+			setupMocks: func(m *svcPackageExecuteMock) {
+				m.ws.EXPECT().ReadWorkloadManifest("api").Return([]byte(lbwsMft), nil)
+				m.interpolator.EXPECT().Interpolate(lbwsMft).Return(lbwsMft, nil)
+				m.mft = &mockWorkloadMft{
+					mockRequiredEnvironmentFeatures: func() []string {
+						return []string{}
+					},
+				}
+				m.envFeaturesDescriber.EXPECT().Version().Return("v1.mock", nil)
+				m.envFeaturesDescriber.EXPECT().AvailableFeatures().Return([]string{}, nil)
+				m.generator.EXPECT().GenerateCloudFormationTemplate(gomock.Any()).Return(&deploy.GenerateCloudFormationTemplateOutput{
+					Template:   "mystack",
+					Parameters: "myparams",
+				}, nil)
+				m.generator.EXPECT().DeployDiff(gomock.Eq("mystack")).Return("", errors.New("some error"))
+			},
+			wantedErr: errors.New("some error"),
+		},
+		"writes the diff": {
+			inVars: packageSvcVars{
+				name:             "api",
+				clientConfigured: true,
+				showDiff:         true,
+			},
+			setupMocks: func(m *svcPackageExecuteMock) {
+				m.ws.EXPECT().ReadWorkloadManifest("api").Return([]byte(lbwsMft), nil)
+				m.interpolator.EXPECT().Interpolate(lbwsMft).Return(lbwsMft, nil)
+				m.mft = &mockWorkloadMft{
+					mockRequiredEnvironmentFeatures: func() []string {
+						return []string{}
+					},
+				}
+				m.envFeaturesDescriber.EXPECT().Version().Return("v1.mock", nil)
+				m.envFeaturesDescriber.EXPECT().AvailableFeatures().Return([]string{}, nil)
+				m.generator.EXPECT().GenerateCloudFormationTemplate(gomock.Any()).Return(&deploy.GenerateCloudFormationTemplateOutput{
+					Template:   "mystack",
+					Parameters: "myparams",
+				}, nil)
+				m.generator.EXPECT().DeployDiff(gomock.Eq("mystack")).Return("mock diff", nil)
+			},
+			wantedDiff: "mock diff",
+			wantedErr:  &errHasDiff{},
+		},
 		"writes service template without addons": {
 			inVars: packageSvcVars{
 				appName:          "ecs-kudos",
@@ -200,11 +246,19 @@ count: 1`
 			setupMocks: func(m *svcPackageExecuteMock) {
 				m.ws.EXPECT().ReadWorkloadManifest("api").Return([]byte(lbwsMft), nil)
 				m.generator.EXPECT().UploadArtifacts().Return(&deploy.UploadArtifactsOutput{
-					ImageDigest: aws.String(mockDigest),
+					ImageDigests: map[string]deploy.ContainerImageIdentifier{
+						"api": {
+							Digest: mockDigest,
+						},
+					},
 				}, nil)
 				m.generator.EXPECT().GenerateCloudFormationTemplate(&deploy.GenerateCloudFormationTemplateInput{
 					StackRuntimeConfiguration: deploy.StackRuntimeConfiguration{
-						ImageDigest: aws.String(mockDigest),
+						ImageDigests: map[string]deploy.ContainerImageIdentifier{
+							"api": {
+								Digest: mockDigest,
+							},
+						},
 						RootUserARN: mockARN,
 					},
 				}).Return(&deploy.GenerateCloudFormationTemplateOutput{
@@ -267,6 +321,7 @@ count: 1`
 			stackBuf := new(bytes.Buffer)
 			paramsBuf := new(bytes.Buffer)
 			addonsBuf := new(bytes.Buffer)
+			diffBuff := new(bytes.Buffer)
 
 			m := &svcPackageExecuteMock{
 				ws:                   mocks.NewMockwsWlDirReader(ctrl),
@@ -281,6 +336,8 @@ count: 1`
 				templateWriter: mockWriteCloser{w: stackBuf},
 				paramsWriter:   mockWriteCloser{w: paramsBuf},
 				addonsWriter:   mockWriteCloser{w: addonsBuf},
+				diffWriter:     mockWriteCloser{w: diffBuff},
+
 				unmarshal: func(b []byte) (manifest.DynamicWorkload, error) {
 					return m.mft, nil
 				},
@@ -302,10 +359,15 @@ count: 1`
 			err := opts.Execute()
 
 			// THEN
-			require.Equal(t, tc.wantedErr, err)
-			require.Equal(t, tc.wantedStack, stackBuf.String())
-			require.Equal(t, tc.wantedParams, paramsBuf.String())
-			require.Equal(t, tc.wantedAddons, addonsBuf.String())
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			} else {
+				require.NoError(t, err)
+			}
+			require.Equal(t, stackBuf.String(), tc.wantedStack)
+			require.Equal(t, paramsBuf.String(), tc.wantedParams)
+			require.Equal(t, addonsBuf.String(), tc.wantedAddons)
+			require.Equal(t, diffBuff.String(), tc.wantedDiff)
 		})
 	}
 }
