@@ -6,6 +6,7 @@ package stack
 import (
 	"bytes"
 	"errors"
+	"fmt"
 	"testing"
 	"time"
 
@@ -273,9 +274,11 @@ Outputs:
 			},
 			Manifest: mft,
 			RuntimeConfig: RuntimeConfig{
-				Image: &ECRImage{
-					RepoURL:  testImageRepoURL,
-					ImageTag: testImageTag,
+				PushedImages: map[string]ECRImage{
+					"test": {
+						RepoURL:  testImageRepoURL,
+						ImageTag: testImageTag,
+					},
 				},
 				CustomResourcesURL: map[string]string{
 					"EnvControllerFunction":       "https://my-bucket.s3.Region.amazonaws.com/sha1/envcontroller.zip",
@@ -304,7 +307,6 @@ Outputs:
 				StartPeriod: aws.Int64(0),
 				Timeout:     aws.Int64(10),
 			},
-			HostedZoneAliases: make(template.AliasesForHostedZone),
 			HTTPTargetContainer: template.HTTPTargetContainer{
 				Port: "8080",
 				Name: "api",
@@ -382,29 +384,43 @@ Outputs:
 			DeploymentControllerConfig: manifest.DeploymentControllerConfig{
 				Rolling: aws.String("recreate"),
 			}}
-		mft.RoutingRule = manifest.RoutingRuleConfiguration{
-			Path: aws.String("/albPath"),
-			HealthCheck: manifest.HealthCheckArgsOrString{
-				Union: manifest.AdvancedToUnion[string](manifest.HTTPHealthCheckArgs{
-					Path:               aws.String("/healthz"),
-					Port:               aws.Int(4200),
-					SuccessCodes:       aws.String("418"),
-					HealthyThreshold:   aws.Int64(64),
-					UnhealthyThreshold: aws.Int64(63),
-					Timeout:            (*time.Duration)(aws.Int64(int64(62 * time.Second))),
-					Interval:           (*time.Duration)(aws.Int64(int64(61 * time.Second))),
-					GracePeriod:        (*time.Duration)(aws.Int64(int64(1 * time.Minute))),
-				}),
+		mft.HTTP = manifest.HTTP{
+			Main: manifest.RoutingRule{
+				Path: aws.String("/albPath"),
+				HealthCheck: manifest.HealthCheckArgsOrString{
+					Union: manifest.AdvancedToUnion[string](manifest.HTTPHealthCheckArgs{
+						Path:               aws.String("/healthz"),
+						Port:               aws.Int(4200),
+						SuccessCodes:       aws.String("418"),
+						HealthyThreshold:   aws.Int64(64),
+						UnhealthyThreshold: aws.Int64(63),
+						Timeout:            (*time.Duration)(aws.Int64(int64(62 * time.Second))),
+						Interval:           (*time.Duration)(aws.Int64(int64(61 * time.Second))),
+						GracePeriod:        (*time.Duration)(aws.Int64(int64(1 * time.Minute))),
+					}),
+				},
+				Stickiness:          aws.Bool(true),
+				DeregistrationDelay: (*time.Duration)(aws.Int64(int64(59 * time.Second))),
+				AllowedSourceIps:    []manifest.IPNet{"10.0.1.0/24"},
+				TargetContainer:     aws.String("envoy"),
 			},
-			Stickiness:          aws.Bool(true),
-			DeregistrationDelay: (*time.Duration)(aws.Int64(int64(59 * time.Second))),
-			AllowedSourceIps:    []manifest.IPNet{"10.0.1.0/24"},
-			TargetContainer:     aws.String("envoy"),
 		}
 		mft.Sidecars = map[string]*manifest.SidecarConfig{
 			"envoy": {
+				Image: manifest.Union[*string, manifest.ImageLocationOrBuild]{
+					Advanced: manifest.ImageLocationOrBuild{
+						Build: manifest.BuildArgsOrString{
+							BuildString: aws.String("./Dockerfile"),
+						},
+					},
+				},
 				Port: aws.String("443"),
 			},
+			"nginx": {
+				Image: manifest.Union[*string, manifest.ImageLocationOrBuild]{
+					Basic: aws.String("mockImageURL"),
+				},
+			},
 		}
 		privatePlacement := manifest.PrivateSubnetPlacement
 		mft.Network.VPC.Placement = manifest.PlacementArgOrString{
@@ -440,16 +456,23 @@ Outputs:
 			},
 			Manifest: mft,
 			RuntimeConfig: RuntimeConfig{
-				Image: &ECRImage{
-					RepoURL:  testImageRepoURL,
-					ImageTag: testImageTag,
-				},
-				CustomResourcesURL: map[string]string{
-					"EnvControllerFunction":       "https://my-bucket.s3.Region.amazonaws.com/sha1/envcontroller.zip",
-					"DynamicDesiredCountFunction": "https://my-bucket.s3.Region.amazonaws.com/sha2/count.zip",
+				PushedImages: map[string]ECRImage{
+					"test": {
+						RepoURL:           testImageRepoURL,
+						ImageTag:          testImageTag,
+						MainContainerName: "test",
+						ContainerName:     "test",
+					},
+					"envoy": {
+						RepoURL:           testImageRepoURL,
+						ImageTag:          testImageTag,
+						MainContainerName: "test",
+						ContainerName:     "envoy",
+					},
 				},
 			},
-			Addons: addons,
+			Addons:             addons,
+			ArtifactBucketName: "my-bucket",
 		})
 		svc.parser = parser
 		require.NoError(t, err)
@@ -474,7 +497,7 @@ Outputs:
 			Sidecars: []*template.SidecarOpts{
 				{
 					Name:  "envoy",
-					Image: aws.String(""),
+					Image: aws.String(fmt.Sprintf("%s:%s-%s", testImageRepoURL, "envoy", testImageTag)),
 					PortMappings: []*template.PortMapping{
 						{
 							Protocol:      "tcp",
@@ -483,6 +506,11 @@ Outputs:
 						},
 					},
 				},
+				{
+					Name:         "nginx",
+					Image:        aws.String("mockImageURL"),
+					PortMappings: []*template.PortMapping{},
+				},
 			},
 			HTTPTargetContainer: template.HTTPTargetContainer{
 				Name: "envoy",
@@ -498,17 +526,19 @@ Outputs:
 				Interval:           aws.Int64(61),
 				GracePeriod:        60,
 			},
-			HostedZoneAliases:   make(template.AliasesForHostedZone),
 			DeregistrationDelay: aws.Int64(59),
-			AllowedSourceIps:    []string{"10.0.1.0/24"},
 			CustomResources: map[string]template.S3ObjectLocation{
 				"EnvControllerFunction": {
 					Bucket: "my-bucket",
-					Key:    "sha1/envcontroller.zip",
+					Key:    "manual/scripts/custom-resources/envcontrollerfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
 				},
 				"DynamicDesiredCountFunction": {
 					Bucket: "my-bucket",
-					Key:    "sha2/count.zip",
+					Key:    "manual/scripts/custom-resources/dynamicdesiredcountfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+				},
+				"RulePriorityFunction": {
+					Bucket: "my-bucket",
+					Key:    "manual/scripts/custom-resources/rulepriorityfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
 				},
 			},
 			ExecuteCommand: &template.ExecuteCommandOpts{},
@@ -527,6 +557,31 @@ Outputs:
 			},
 			EntryPoint: []string{"enter", "from"},
 			Command:    []string{"here"},
+			ALBListener: &template.ALBListener{
+				Rules: []template.ALBListenerRule{
+					{
+						Path:            "/albPath",
+						TargetContainer: "envoy",
+						TargetPort:      "443",
+						HTTPHealthCheck: template.HTTPHealthCheckOpts{
+							HealthCheckPath:    "/healthz",
+							GracePeriod:        60,
+							Port:               "4200",
+							SuccessCodes:       "418",
+							HealthyThreshold:   aws.Int64(64),
+							UnhealthyThreshold: aws.Int64(63),
+							Interval:           aws.Int64(61),
+							Timeout:            aws.Int64(62),
+						},
+						AllowedSourceIps: []string{
+							"10.0.1.0/24",
+						},
+						Stickiness: "true",
+					},
+				},
+				HostedZoneAliases: template.AliasesForHostedZone{},
+				MainContainerPort: "8080",
+			},
 			ALBEnabled: true,
 			PortMappings: []*template.PortMapping{
 				{
