@@ -35,8 +35,7 @@ type LoadBalancedWebService struct {
 	publicSubnetCIDRBlocks []string
 	appInfo                deploy.AppInformation
 
-	parser   loadBalancedWebSvcReadParser
-	localCRs []uploadable // Custom resources that have not been uploaded yet.
+	parser loadBalancedWebSvcReadParser
 }
 
 // LoadBalancedWebServiceOption is used to configuring an optional field for LoadBalancedWebService.
@@ -68,9 +67,10 @@ func NewLoadBalancedWebService(conf LoadBalancedWebServiceConfig,
 	if err != nil {
 		return nil, fmt.Errorf("load balanced web service custom resources: %w", err)
 	}
+	conf.RuntimeConfig.loadCustomResourceURLs(conf.ArtifactBucketName, uploadableCRs(crs).convert())
+
 	var dnsDelegationEnabled, httpsEnabled bool
 	var appInfo deploy.AppInformation
-
 	if conf.App.Domain != "" {
 		dnsDelegationEnabled = true
 		appInfo = deploy.AppInformation{
@@ -85,7 +85,7 @@ func NewLoadBalancedWebService(conf LoadBalancedWebServiceConfig,
 		httpsEnabled = true
 		dnsDelegationEnabled = false
 	}
-	if conf.Manifest.RoutingRule.Disabled() {
+	if conf.Manifest.HTTPOrBool.Disabled() {
 		httpsEnabled = false
 	}
 	s := &LoadBalancedWebService{
@@ -102,7 +102,8 @@ func NewLoadBalancedWebService(conf LoadBalancedWebServiceConfig,
 				parser:             fs,
 				addons:             conf.Addons,
 			},
-			logRetention:        conf.Manifest.Logging.Retention,
+			logging:             conf.Manifest.Logging,
+			sidecars:            conf.Manifest.Sidecars,
 			tc:                  conf.Manifest.TaskConfig,
 			taskDefOverrideFunc: override.CloudFormationTemplate,
 		},
@@ -111,8 +112,7 @@ func NewLoadBalancedWebService(conf LoadBalancedWebServiceConfig,
 		appInfo:              appInfo,
 		dnsDelegationEnabled: dnsDelegationEnabled,
 
-		parser:   fs,
-		localCRs: uploadableCRs(crs).convert(),
+		parser: fs,
 	}
 	for _, opt := range opts {
 		opt(s)
@@ -139,10 +139,7 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 	if err != nil {
 		return "", fmt.Errorf("parse exposed ports in service manifest %s: %w", s.name, err)
 	}
-	sidecars, err := convertSidecars(s.manifest.Sidecars, exposedPorts.PortsForContainer)
-	if err != nil {
-		return "", fmt.Errorf("convert the sidecar configuration for service %s: %w", s.name, err)
-	}
+	sidecars, err := convertSidecars(s.manifest.Sidecars, exposedPorts.PortsForContainer, s.rc)
 	if err != nil {
 		return "", fmt.Errorf("convert the sidecar configuration for service %s: %w", s.name, err)
 	}
@@ -174,40 +171,24 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 	if err != nil {
 		return "", err
 	}
-
-	var aliases []string
-	if s.httpsEnabled {
-		if aliases, err = convertAlias(s.manifest.RoutingRule.Alias); err != nil {
-			return "", err
-		}
-	}
-
-	aliasesFor, err := convertHostedZone(s.manifest.RoutingRule.RoutingRuleConfiguration)
-	if err != nil {
-		return "", err
-	}
 	var deregistrationDelay *int64 = aws.Int64(60)
-	if s.manifest.RoutingRule.DeregistrationDelay != nil {
-		deregistrationDelay = aws.Int64(int64(s.manifest.RoutingRule.DeregistrationDelay.Seconds()))
-	}
-	var allowedSourceIPs []string
-	for _, ipNet := range s.manifest.RoutingRule.AllowedSourceIps {
-		allowedSourceIPs = append(allowedSourceIPs, string(ipNet))
+	if s.manifest.HTTPOrBool.Main.DeregistrationDelay != nil {
+		deregistrationDelay = aws.Int64(int64(s.manifest.HTTPOrBool.Main.DeregistrationDelay.Seconds()))
 	}
 	nlbConfig, err := s.convertNetworkLoadBalancer()
 	if err != nil {
 		return "", err
 	}
-	httpRedirect := true
-	if s.manifest.RoutingRule.RedirectToHTTPS != nil {
-		httpRedirect = aws.BoolValue(s.manifest.RoutingRule.RedirectToHTTPS)
+	albListenerConfig, err := s.convertALBListener()
+	if err != nil {
+		return "", err
 	}
 	var scConfig *template.ServiceConnect
 	if s.manifest.Network.Connect.Enabled() {
 		scConfig = convertServiceConnect(s.manifest.Network.Connect)
 	}
 
-	targetContainer, targetContainerPort, err := s.manifest.HTTPLoadBalancerTarget()
+	targetContainer, targetContainerPort, err := s.manifest.HTTPOrBool.Main.Target(exposedPorts)
 	if err != nil {
 		return "", err
 	}
@@ -250,19 +231,14 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 		Storage:                 convertStorageOpts(s.manifest.Name, s.manifest.Storage),
 
 		// ALB configs.
-		ALBEnabled:          !s.manifest.RoutingRule.Disabled(),
-		Aliases:             aliases,
-		AllowedSourceIps:    allowedSourceIPs,
+		ALBEnabled:          !s.manifest.HTTPOrBool.Disabled(),
 		DeregistrationDelay: deregistrationDelay,
-		HostedZoneAliases:   aliasesFor,
-		HTTPSListener:       s.httpsEnabled,
-		HTTPRedirect:        httpRedirect,
 		HTTPTargetContainer: template.HTTPTargetContainer{
 			Port: targetContainerPort,
 			Name: targetContainer,
 		},
-		HTTPHealthCheck: convertHTTPHealthCheck(&s.manifest.RoutingRule.HealthCheck),
-		HTTPVersion:     convertHTTPVersion(s.manifest.RoutingRule.ProtocolVersion),
+		HTTPHealthCheck: convertHTTPHealthCheck(&s.manifest.HTTPOrBool.Main.HealthCheck),
+		ALBListener:     albListenerConfig,
 
 		// NLB configs.
 		AppDNSName:           nlbConfig.appDNSName,
@@ -300,11 +276,11 @@ func (s *LoadBalancedWebService) Parameters() ([]*cloudformation.Parameter, erro
 	if err != nil {
 		return nil, err
 	}
-	targetContainer, targetPort, err := s.manifest.HTTPLoadBalancerTarget()
+	exposedPorts, err := s.manifest.ExposedPorts()
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("parse exposed ports in service manifest %s: %w", s.name, err)
 	}
-
+	targetContainer, targetPort, err := s.manifest.HTTPOrBool.Main.Target(exposedPorts)
 	if err != nil {
 		return nil, err
 	}
@@ -325,30 +301,22 @@ func (s *LoadBalancedWebService) Parameters() ([]*cloudformation.Parameter, erro
 			ParameterKey:   aws.String(WorkloadTargetPortParamKey),
 			ParameterValue: aws.String(targetPort),
 		},
-		{
-			ParameterKey:   aws.String(WorkloadEnvFileARNParamKey),
-			ParameterValue: aws.String(s.rc.EnvFileARN),
-		},
 	}...)
 
-	if !s.manifest.RoutingRule.Disabled() {
+	if !s.manifest.HTTPOrBool.Disabled() {
 		wkldParams = append(wkldParams, []*cloudformation.Parameter{
 			{
 				ParameterKey:   aws.String(WorkloadRulePathParamKey),
-				ParameterValue: s.manifest.RoutingRule.Path,
+				ParameterValue: s.manifest.HTTPOrBool.Main.Path,
 			},
 			{
 				ParameterKey:   aws.String(WorkloadHTTPSParamKey),
 				ParameterValue: aws.String(strconv.FormatBool(s.httpsEnabled)),
 			},
-			{
-				ParameterKey:   aws.String(WorkloadStickinessParamKey),
-				ParameterValue: aws.String(strconv.FormatBool(aws.BoolValue(s.manifest.RoutingRule.Stickiness))),
-			},
 		}...)
 	}
 	if !s.manifest.NLBConfig.IsEmpty() {
-		port, _, err := manifest.ParsePortMapping(s.manifest.NLBConfig.Port)
+		port, _, err := manifest.ParsePortMapping(s.manifest.NLBConfig.Listener.Port)
 		if err != nil {
 			return nil, err
 		}
