@@ -201,7 +201,7 @@ Outputs:
 		mft.ImageConfig.HealthCheck = manifest.ContainerHealthCheck{
 			Retries: aws.Int(5),
 		}
-		mft.RoutingRule.Alias = manifest.Alias{AdvancedAliases: []manifest.AdvancedAlias{
+		mft.HTTPOrBool.Main.Alias = manifest.Alias{AdvancedAliases: []manifest.AdvancedAlias{
 			{
 				Alias:      aws.String("mockAlias"),
 				HostedZone: aws.String("mockHostedZone"),
@@ -240,14 +240,17 @@ Outputs:
 			},
 			Manifest: mft,
 			RuntimeConfig: RuntimeConfig{
-				Image: &ECRImage{
-					RepoURL:  testImageRepoURL,
-					ImageTag: testImageTag,
+				PushedImages: map[string]ECRImage{
+					"test": {
+						RepoURL:  testImageRepoURL,
+						ImageTag: testImageTag,
+					},
 				},
 				AccountID: "0123456789012",
 				Region:    "us-west-2",
 			},
-			Addons: mockAddons{},
+			Addons:             mockAddons{},
+			ArtifactBucketName: "bucket",
 		}, func(s *LoadBalancedWebService) {
 			s.parser = parser
 		})
@@ -267,12 +270,6 @@ Outputs:
 				HealthCheckPath: "/",
 				GracePeriod:     60,
 			},
-			HostedZoneAliases: template.AliasesForHostedZone{
-				"mockHostedZone": []string{"mockAlias"},
-			},
-			Aliases:             []string{"mockAlias"},
-			HTTPSListener:       true,
-			HTTPRedirect:        true,
 			DeregistrationDelay: aws.Int64(60),
 			HTTPTargetContainer: template.HTTPTargetContainer{
 				Name: "frontend",
@@ -288,7 +285,28 @@ Outputs:
 				Timeout:     aws.Int64(5),
 				Retries:     aws.Int64(5),
 			},
-			CustomResources: make(map[string]template.S3ObjectLocation),
+			CustomResources: map[string]template.S3ObjectLocation{
+				"DynamicDesiredCountFunction": {
+					Bucket: "bucket",
+					Key:    "manual/scripts/custom-resources/dynamicdesiredcountfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+				},
+				"EnvControllerFunction": {
+					Bucket: "bucket",
+					Key:    "manual/scripts/custom-resources/envcontrollerfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+				},
+				"NLBCertValidatorFunction": {
+					Bucket: "bucket",
+					Key:    "manual/scripts/custom-resources/nlbcertvalidatorfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+				},
+				"NLBCustomDomainFunction": {
+					Bucket: "bucket",
+					Key:    "manual/scripts/custom-resources/nlbcustomdomainfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+				},
+				"RulePriorityFunction": {
+					Bucket: "bucket",
+					Key:    "manual/scripts/custom-resources/rulepriorityfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+				},
+			},
 			Network: template.NetworkOpts{
 				AssignPublicIP: template.EnablePublicIP,
 				SubnetsType:    template.PublicSubnetsPlacement,
@@ -300,6 +318,32 @@ Outputs:
 			},
 			EntryPoint: []string{"/bin/echo", "hello"},
 			Command:    []string{"world"},
+			ALBListener: &template.ALBListener{
+				Rules: []template.ALBListenerRule{
+					{
+						Path:            "frontend",
+						TargetContainer: "frontend",
+						TargetPort:      "80",
+						Aliases: []string{
+							"mockAlias",
+						},
+						HTTPHealthCheck: template.HTTPHealthCheckOpts{
+							HealthCheckPath: "/",
+							GracePeriod:     60,
+							Port:            "",
+							SuccessCodes:    "",
+						},
+						Stickiness:      "false",
+						RedirectToHTTPS: true,
+					},
+				},
+				IsHTTPS: true,
+				HostedZoneAliases: template.AliasesForHostedZone{
+					"mockHostedZone": {
+						"mockAlias",
+					},
+				},
+			},
 			ALBEnabled: true,
 			PortMappings: []*template.PortMapping{
 				{
@@ -403,7 +447,7 @@ Outputs:
 			Path: "frontend",
 			Port: 80,
 		})
-		mft.RoutingRule.TargetContainer = aws.String("envoy")
+		mft.HTTPOrBool.Main.TargetContainer = aws.String("envoy")
 		mft.Sidecars = map[string]*manifest.SidecarConfig{
 			"envoy": {
 				Port: aws.String("443"),
@@ -538,10 +582,6 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(WorkloadRulePathParamKey),
 					ParameterValue: aws.String("frontend"),
 				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("false"),
-				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
 					ParameterValue: aws.String("false"),
@@ -582,10 +622,6 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(WorkloadTaskCountParamKey),
 					ParameterValue: aws.String("2"),
 				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("false"),
-				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
 					ParameterValue: aws.String("false"),
@@ -595,7 +631,7 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 		"with sidecar container": {
 			httpsEnabled: true,
 			setupManifest: func(service *manifest.LoadBalancedWebService) {
-				service.RoutingRule.TargetContainer = aws.String("xray")
+				service.HTTPOrBool.Main.TargetContainer = aws.String("xray")
 				service.Sidecars = map[string]*manifest.SidecarConfig{
 					"xray": {
 						Port: aws.String("5000"),
@@ -623,46 +659,6 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(WorkloadTaskCountParamKey),
 					ParameterValue: aws.String("1"),
 				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("false"),
-				},
-				{
-					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
-					ParameterValue: aws.String("false"),
-				},
-			}...),
-		},
-		"Stickiness enabled": {
-			httpsEnabled: false,
-			setupManifest: func(service *manifest.LoadBalancedWebService) {
-				service.RoutingRule.Stickiness = aws.Bool(true)
-			},
-			expectedParams: append(expectedParams, []*cloudformation.Parameter{
-				{
-					ParameterKey:   aws.String(WorkloadRulePathParamKey),
-					ParameterValue: aws.String("frontend"),
-				},
-				{
-					ParameterKey:   aws.String(WorkloadHTTPSParamKey),
-					ParameterValue: aws.String("false"),
-				},
-				{
-					ParameterKey:   aws.String(WorkloadTargetContainerParamKey),
-					ParameterValue: aws.String("frontend"),
-				},
-				{
-					ParameterKey:   aws.String(WorkloadTargetPortParamKey),
-					ParameterValue: aws.String("80"),
-				},
-				{
-					ParameterKey:   aws.String(WorkloadTaskCountParamKey),
-					ParameterValue: aws.String("1"),
-				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("true"),
-				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
 					ParameterValue: aws.String("false"),
@@ -700,10 +696,6 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(WorkloadTaskCountParamKey),
 					ParameterValue: aws.String("1"),
 				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("false"),
-				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
 					ParameterValue: aws.String("false"),
@@ -743,10 +735,6 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(WorkloadTaskCountParamKey),
 					ParameterValue: aws.String("1"),
 				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("false"),
-				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
 					ParameterValue: aws.String("true"),
@@ -756,7 +744,9 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 		"nlb enabled": {
 			setupManifest: func(service *manifest.LoadBalancedWebService) {
 				service.NLBConfig = manifest.NetworkLoadBalancerConfiguration{
-					Port: aws.String("443/tcp"),
+					Listener: manifest.NetworkLoadBalancerListener{
+						Port: aws.String("443/tcp"),
+					},
 				}
 			},
 			expectedParams: append(expectedParams, []*cloudformation.Parameter{
@@ -780,10 +770,6 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(WorkloadTaskCountParamKey),
 					ParameterValue: aws.String("1"),
 				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("false"),
-				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
 					ParameterValue: aws.String("false"),
@@ -801,13 +787,15 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 		"nlb alias enabled": {
 			setupManifest: func(service *manifest.LoadBalancedWebService) {
 				service.NLBConfig = manifest.NetworkLoadBalancerConfiguration{
+					Listener: manifest.NetworkLoadBalancerListener{
+						Port: aws.String("443/tcp"),
+					},
 					Aliases: manifest.Alias{
 						AdvancedAliases: []manifest.AdvancedAlias{
 							{Alias: aws.String("example.com")},
 							{Alias: aws.String("v1.example.com")},
 						},
 					},
-					Port: aws.String("443/tcp"),
 				}
 			},
 			expectedParams: append(expectedParams, []*cloudformation.Parameter{
@@ -831,10 +819,6 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(WorkloadTaskCountParamKey),
 					ParameterValue: aws.String("1"),
 				},
-				{
-					ParameterKey:   aws.String(WorkloadStickinessParamKey),
-					ParameterValue: aws.String("false"),
-				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
 					ParameterValue: aws.String("false"),
@@ -851,7 +835,7 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 		},
 		"do not render http params when disabled": {
 			setupManifest: func(service *manifest.LoadBalancedWebService) {
-				service.RoutingRule = manifest.RoutingRuleConfigOrBool{
+				service.HTTPOrBool = manifest.HTTPOrBool{
 					Enabled: aws.Bool(false),
 				}
 			},
@@ -902,9 +886,11 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 						env:  testEnvName,
 						app:  testAppName,
 						rc: RuntimeConfig{
-							Image: &ECRImage{
-								RepoURL:  testImageRepoURL,
-								ImageTag: testImageTag,
+							PushedImages: map[string]ECRImage{
+								aws.StringValue(testManifest.Name): {
+									RepoURL:  testImageRepoURL,
+									ImageTag: testImageTag,
+								},
 							},
 						},
 					},
@@ -945,9 +931,11 @@ func TestLoadBalancedWebService_SerializedParameters(t *testing.T) {
 				env:  testEnvName,
 				app:  testAppName,
 				rc: RuntimeConfig{
-					Image: &ECRImage{
-						RepoURL:  testImageRepoURL,
-						ImageTag: testImageTag,
+					PushedImages: map[string]ECRImage{
+						"frontend": {
+							RepoURL:  testImageRepoURL,
+							ImageTag: testImageTag,
+						},
 					},
 					AdditionalTags: map[string]string{
 						"owner": "boss",
@@ -973,7 +961,6 @@ func TestLoadBalancedWebService_SerializedParameters(t *testing.T) {
     "HTTPSEnabled": "false",
     "LogRetention": "30",
     "RulePath": "frontend",
-    "Stickiness": "false",
     "TargetContainer": "frontend",
     "TargetPort": "80",
     "TaskCPU": "256",
@@ -1007,9 +994,11 @@ func TestLoadBalancedWebService_Tags(t *testing.T) {
 				env:  testEnvName,
 				app:  testAppName,
 				rc: RuntimeConfig{
-					Image: &ECRImage{
-						RepoURL:  testImageRepoURL,
-						ImageTag: testImageTag,
+					PushedImages: map[string]ECRImage{
+						"frontend": {
+							RepoURL:  testImageRepoURL,
+							ImageTag: testImageTag,
+						},
 					},
 					AdditionalTags: map[string]string{
 						"owner":              "boss",
