@@ -65,11 +65,12 @@ func TestRequestDrivenWebService_NewRequestDrivenWebService(t *testing.T) {
 	fs = templatetest.Stub{}
 
 	type testInput struct {
-		mft     *manifest.RequestDrivenWebService
-		env     string
-		rc      RuntimeConfig
-		appInfo deploy.AppInformation
-		urls    map[string]string
+		mft        *manifest.RequestDrivenWebService
+		env        string
+		rc         RuntimeConfig
+		bucketName string
+		appInfo    deploy.AppInformation
+		urls       map[string]string
 	}
 
 	testCases := map[string]struct {
@@ -83,10 +84,13 @@ func TestRequestDrivenWebService_NewRequestDrivenWebService(t *testing.T) {
 			input: testInput{
 				mft: testRDWebServiceManifest,
 				env: testEnvName,
-				rc:  RuntimeConfig{},
+				rc: RuntimeConfig{
+					Region: "us-west-2",
+				},
 				appInfo: deploy.AppInformation{
 					Name: testAppName,
 				},
+				bucketName: "mockbucket",
 				urls: map[string]string{
 					"custom-domain-app-runner": "mockURL1",
 					"aws-sdk-layer":            "mockURL2",
@@ -96,10 +100,16 @@ func TestRequestDrivenWebService_NewRequestDrivenWebService(t *testing.T) {
 			wantedStack: &RequestDrivenWebService{
 				appRunnerWkld: &appRunnerWkld{
 					wkld: &wkld{
-						name:  aws.StringValue(testRDWebServiceManifest.Name),
-						env:   testEnvName,
-						app:   testAppName,
-						rc:    RuntimeConfig{},
+						name: aws.StringValue(testRDWebServiceManifest.Name),
+						env:  testEnvName,
+						app:  testAppName,
+						rc: RuntimeConfig{
+							CustomResourcesURL: map[string]string{
+								"CustomDomainFunction":  "https://.s3.us-west-2.amazonaws.com/manual/scripts/custom-resources/customdomainfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+								"EnvControllerFunction": "https://.s3.us-west-2.amazonaws.com/manual/scripts/custom-resources/envcontrollerfunction/8932747ba5dbff619d89b92d0033ef1d04f7dd1b055e073254907d4e38e3976d.zip",
+							},
+							Region: "us-west-2",
+						},
 						image: testRDWebServiceManifest.ImageConfig.Image,
 					},
 					instanceConfig: testRDWebServiceManifest.InstanceConfig,
@@ -325,9 +335,11 @@ Outputs:
 						env:  testEnvName,
 						app:  testAppName,
 						rc: RuntimeConfig{
-							Image: &ECRImage{
-								RepoURL:  testImageRepoURL,
-								ImageTag: testImageTag,
+							PushedImages: map[string]ECRImage{
+								"testServiceName": {
+									RepoURL:  testImageRepoURL,
+									ImageTag: testImageTag,
+								},
 							},
 							ServiceDiscoveryEndpoint: mockSD,
 							AccountID:                "0123456789012",
@@ -483,9 +495,11 @@ func TestRequestDrivenWebService_SerializedParameters(t *testing.T) {
 				env:  testEnvName,
 				app:  testAppName,
 				rc: RuntimeConfig{
-					Image: &ECRImage{
-						RepoURL:  testImageRepoURL,
-						ImageTag: testImageTag,
+					PushedImages: map[string]ECRImage{
+						aws.StringValue(testRDWebServiceManifest.Name): {
+							RepoURL:  testImageRepoURL,
+							ImageTag: testImageTag,
+						},
 					},
 				},
 			},
