@@ -81,7 +81,7 @@ func convertPortMappings(exposedPorts []manifest.ExposedPort) []*template.PortMa
 }
 
 // convertSidecars converts the manifest sidecar configuration into a format parsable by the templates pkg.
-func convertSidecars(s map[string]*manifest.SidecarConfig, exposedPorts map[string][]manifest.ExposedPort) ([]*template.SidecarOpts, error) {
+func convertSidecars(s map[string]*manifest.SidecarConfig, exposedPorts map[string][]manifest.ExposedPort, rc RuntimeConfig) ([]*template.SidecarOpts, error) {
 	var sidecars []*template.SidecarOpts
 	if s == nil {
 		return nil, nil
@@ -95,7 +95,10 @@ func convertSidecars(s map[string]*manifest.SidecarConfig, exposedPorts map[stri
 	sort.Strings(keys)
 	for _, name := range keys {
 		config := s[name]
-		imageURI, _ := config.ImageURI()
+		imageURI := rc.PushedImages[name].URI()
+		if uri, hasLocation := config.ImageURI(); hasLocation {
+			imageURI = uri
+		}
 		entrypoint, err := convertEntryPoint(config.EntryPoint)
 		if err != nil {
 			return nil, err
@@ -141,16 +144,21 @@ func convertContainerHealthCheck(hc manifest.ContainerHealthCheck) *template.Con
 	}
 }
 
-func convertHostedZone(m manifest.RoutingRuleConfiguration) (template.AliasesForHostedZone, error) {
+func convertHostedZone(alias manifest.Alias, defaultHostedZone *string) (template.AliasesForHostedZone, error) {
 	aliasesFor := make(map[string][]string)
-	defaultHostedZone := m.HostedZone
-	if len(m.Alias.AdvancedAliases) != 0 {
-		for _, alias := range m.Alias.AdvancedAliases {
+	if len(alias.AdvancedAliases) != 0 {
+		for _, alias := range alias.AdvancedAliases {
 			if alias.HostedZone != nil {
+				if isDuplicateAliasEntry(aliasesFor[*alias.HostedZone], aws.StringValue(alias.Alias)) {
+					continue
+				}
 				aliasesFor[*alias.HostedZone] = append(aliasesFor[*alias.HostedZone], *alias.Alias)
 				continue
 			}
 			if defaultHostedZone != nil {
+				if isDuplicateAliasEntry(aliasesFor[*defaultHostedZone], aws.StringValue(alias.Alias)) {
+					continue
+				}
 				aliasesFor[*defaultHostedZone] = append(aliasesFor[*defaultHostedZone], *alias.Alias)
 			}
 		}
@@ -159,14 +167,30 @@ func convertHostedZone(m manifest.RoutingRuleConfiguration) (template.AliasesFor
 	if defaultHostedZone == nil {
 		return aliasesFor, nil
 	}
-	aliases, err := m.Alias.ToStringSlice()
+	aliases, err := alias.ToStringSlice()
 	if err != nil {
 		return nil, err
 	}
-	aliasesFor[*defaultHostedZone] = aliases
+
+	for _, alias := range aliases {
+		if isDuplicateAliasEntry(aliasesFor[*defaultHostedZone], alias) {
+			continue
+		}
+		aliasesFor[*defaultHostedZone] = append(aliasesFor[*defaultHostedZone], alias)
+	}
+
 	return aliasesFor, nil
 }
 
+func isDuplicateAliasEntry(aliasList []string, alias string) bool {
+	for _, entry := range aliasList {
+		if entry == alias {
+			return true
+		}
+	}
+	return false
+}
+
 // convertDependsOn converts image and sidecar depends on fields to have upper case statuses.
 func convertDependsOn(d manifest.DependsOn) map[string]string {
 	if d == nil {
@@ -460,26 +484,166 @@ func convertEnvSecurityGroupCfg(mft *manifest.Environment) (*template.SecurityGr
 	}, nil
 }
 
+func (s *LoadBalancedWebService) convertALBListener() (*template.ALBListener, error) {
+	rrConfig := s.manifest.HTTPOrBool
+	if rrConfig.Disabled() || rrConfig.IsEmpty() {
+		return nil, nil
+	}
+	var rules []template.ALBListenerRule
+	var aliasesFor template.AliasesForHostedZone
+	for _, routingRule := range rrConfig.RoutingRules() {
+		httpRedirect := true
+		if routingRule.RedirectToHTTPS != nil {
+			httpRedirect = aws.BoolValue(routingRule.RedirectToHTTPS)
+		}
+		rule, err := routingRuleConfigConverter{
+			rule:            routingRule,
+			manifest:        s.manifest,
+			httpsEnabled:    s.httpsEnabled,
+			redirectToHTTPS: httpRedirect,
+		}.convert()
+		if err != nil {
+			return nil, err
+		}
+		rules = append(rules, *rule)
+		aliasesFor, err = convertHostedZone(rrConfig.Main.Alias, rrConfig.Main.HostedZone)
+		if err != nil {
+			return nil, err
+		}
+	}
+	return &template.ALBListener{
+		Rules:             rules,
+		IsHTTPS:           s.httpsEnabled,
+		HostedZoneAliases: aliasesFor,
+	}, nil
+}
+
+func (s *BackendService) convertALBListener() (*template.ALBListener, error) {
+	rrConfig := s.manifest.HTTP
+	if rrConfig.IsEmpty() {
+		return nil, nil
+	}
+	var rules []template.ALBListenerRule
+	var hostedZoneAliases template.AliasesForHostedZone
+	for _, routingRule := range rrConfig.RoutingRules() {
+		rule, err := routingRuleConfigConverter{
+			rule:            routingRule,
+			manifest:        s.manifest,
+			httpsEnabled:    s.httpsEnabled,
+			redirectToHTTPS: s.httpsEnabled,
+		}.convert()
+		if err != nil {
+			return nil, err
+		}
+		rules = append(rules, *rule)
+		hostedZoneAliases, err = convertHostedZone(rrConfig.Main.Alias, rrConfig.Main.HostedZone)
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	return &template.ALBListener{
+		Rules:             rules,
+		IsHTTPS:           s.httpsEnabled,
+		MainContainerPort: s.manifest.MainContainerPort(),
+		HostedZoneAliases: hostedZoneAliases,
+	}, nil
+}
+
+type loadBalancerTargeter interface {
+	MainContainerPort() string
+	ExposedPorts() (manifest.ExposedPortsIndex, error)
+}
+
+type routingRuleConfigConverter struct {
+	rule            manifest.RoutingRule
+	manifest        loadBalancerTargeter
+	httpsEnabled    bool
+	redirectToHTTPS bool
+}
+
+func (conv routingRuleConfigConverter) convert() (*template.ALBListenerRule, error) {
+	var aliases []string
+	var err error
+
+	exposedPorts, err := conv.manifest.ExposedPorts()
+	if err != nil {
+		return nil, err
+	}
+	targetContainer, targetPort, err := conv.rule.Target(exposedPorts)
+	if err != nil {
+		return nil, err
+	}
+
+	if conv.httpsEnabled {
+		aliases, err = convertAlias(conv.rule.Alias)
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	config := &template.ALBListenerRule{
+		Path:             aws.StringValue(conv.rule.Path),
+		TargetContainer:  targetContainer,
+		TargetPort:       targetPort,
+		Aliases:          aliases,
+		HTTPHealthCheck:  convertHTTPHealthCheck(&conv.rule.HealthCheck),
+		AllowedSourceIps: convertAllowedSourceIPs(conv.rule.AllowedSourceIps),
+		Stickiness:       strconv.FormatBool(aws.BoolValue(conv.rule.Stickiness)),
+		HTTPVersion:      aws.StringValue(convertHTTPVersion(conv.rule.ProtocolVersion)),
+		RedirectToHTTPS:  conv.redirectToHTTPS,
+	}
+	return config, nil
+}
+
+type nlbListeners []template.NetworkLoadBalancerListener
+
+// isCertRequired returns true if any of the NLB listeners have protocol as TLS set.
+func (ls nlbListeners) isCertRequired() bool {
+	for _, listener := range ls {
+		if listener.Protocol == manifest.TLS {
+			return true
+		}
+	}
+	return false
+}
+
 func (s *LoadBalancedWebService) convertNetworkLoadBalancer() (networkLoadBalancerConfig, error) {
 	nlbConfig := s.manifest.NLBConfig
 	if nlbConfig.IsEmpty() {
 		return networkLoadBalancerConfig{}, nil
 	}
-
-	// Parse targetContainer and targetPort for the Network Load Balancer targets.
-	targetContainer, targetPort, err := s.manifest.NetworkLoadBalancerTarget()
+	exposedPorts, err := s.manifest.ExposedPorts()
 	if err != nil {
 		return networkLoadBalancerConfig{}, err
 	}
+	listeners := make(nlbListeners, len(nlbConfig.NLBListeners()))
+	for idx, listener := range nlbConfig.NLBListeners() {
+		// Parse targetContainer and targetPort for the Network Load Balancer targets.
+		targetContainer, targetPort, err := listener.Target(exposedPorts)
+		if err != nil {
+			return networkLoadBalancerConfig{}, err
+		}
 
-	// Parse listener port and protocol.
-	port, protocol, err := manifest.ParsePortMapping(nlbConfig.Port)
-	if err != nil {
-		return networkLoadBalancerConfig{}, err
-	}
+		// Parse listener port and protocol.
+		port, protocol, err := manifest.ParsePortMapping(listener.Port)
+		if err != nil {
+			return networkLoadBalancerConfig{}, err
+		}
 
-	if protocol == nil {
-		protocol = aws.String(defaultNLBProtocol)
+		if protocol == nil {
+			protocol = aws.String(defaultNLBProtocol)
+		}
+
+		listeners[idx] = template.NetworkLoadBalancerListener{
+			Port:            aws.StringValue(port),
+			Protocol:        strings.ToUpper(aws.StringValue(protocol)),
+			TargetContainer: targetContainer,
+			TargetPort:      targetPort,
+			SSLPolicy:       listener.SSLPolicy,
+			HealthCheck:     convertNLBHealthCheck(&listener.HealthCheck),
+			Stickiness:      listener.Stickiness,
+		}
 	}
 
 	aliases, err := convertAlias(nlbConfig.Aliases)
@@ -487,25 +651,13 @@ func (s *LoadBalancedWebService) convertNetworkLoadBalancer() (networkLoadBalanc
 		return networkLoadBalancerConfig{}, fmt.Errorf(`convert "nlb.alias" to string slice: %w`, err)
 	}
 
-	hc := convertNLBHealthCheck(&nlbConfig.HealthCheck)
-
 	config := networkLoadBalancerConfig{
 		settings: &template.NetworkLoadBalancer{
-			PublicSubnetCIDRs: s.publicSubnetCIDRBlocks,
-			Listener: []template.NetworkLoadBalancerListener{
-				{
-					Port:            aws.StringValue(port),
-					Protocol:        strings.ToUpper(aws.StringValue(protocol)),
-					TargetContainer: targetContainer,
-					TargetPort:      targetPort,
-					SSLPolicy:       nlbConfig.SSLPolicy,
-					Aliases:         aliases,
-					HealthCheck:     hc,
-					Stickiness:      nlbConfig.Stickiness,
-				},
-			},
+			PublicSubnetCIDRs:   s.publicSubnetCIDRBlocks,
+			Listener:            listeners,
+			Aliases:             aliases,
 			MainContainerPort:   s.manifest.MainContainerPort(),
-			CertificateRequired: strings.ToUpper(aws.StringValue(protocol)) == manifest.TLS,
+			CertificateRequired: listeners.isCertRequired(),
 		},
 	}
 
@@ -524,6 +676,14 @@ func convertExecuteCommand(e *manifest.ExecuteCommand) *template.ExecuteCommandO
 	return &template.ExecuteCommandOpts{}
 }
 
+func convertAllowedSourceIPs(allowedSourceIPs []manifest.IPNet) []string {
+	var sourceIPs []string
+	for _, ipNet := range allowedSourceIPs {
+		sourceIPs = append(sourceIPs, string(ipNet))
+	}
+	return sourceIPs
+}
+
 func convertServiceConnect(s manifest.ServiceConnectBoolOrArgs) *template.ServiceConnect {
 	return &template.ServiceConnect{
 		Alias: s.ServiceConnectArgs.Alias,
