@@ -148,12 +148,102 @@ func TestServiceStatus_Describe(t *testing.T) {
 					m.ecsServiceGetter.EXPECT().Service(mockCluster, mockService).Return(&awsecs.Service{}, nil),
 					m.alarmStatusGetter.EXPECT().AlarmsWithTags(gomock.Any()).Return([]cloudwatch.AlarmStatus{}, nil),
 					m.aas.EXPECT().ECSServiceAlarmNames(mockCluster, mockService).Return([]string{"mockAlarmName"}, nil),
-					m.alarmStatusGetter.EXPECT().AlarmStatus([]string{"mockAlarmName"}).Return(nil, mockError),
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return(nil, mockError),
 				)
 			},
 
 			wantedError: fmt.Errorf("get auto scaling CloudWatch alarms: some error"),
 		},
+		"errors if failed to get Copilot-created CloudWatch rollback alarm status": {
+			setupMocks: func(m serviceStatusDescriberMocks) {
+				gomock.InOrder(
+					m.serviceDescriber.EXPECT().DescribeService("mockApp", "mockEnv", "mockSvc").Return(mockServiceDesc, nil),
+					m.ecsServiceGetter.EXPECT().Service(mockCluster, mockService).Return(&awsecs.Service{}, nil),
+					m.alarmStatusGetter.EXPECT().AlarmsWithTags(gomock.Any()).Return([]cloudwatch.AlarmStatus{}, nil),
+					m.aas.EXPECT().ECSServiceAlarmNames(mockCluster, mockService).Return([]string{"mockAlarmName"}, nil),
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return(nil, nil),
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return(nil, mockError),
+				)
+			},
+			wantedError: fmt.Errorf("get Copilot-created CloudWatch alarms: some error"),
+		},
+		"do not get status of extraneous alarms": {
+			setupMocks: func(m serviceStatusDescriberMocks) {
+				gomock.InOrder(
+					m.serviceDescriber.EXPECT().DescribeService("mockApp", "mockEnv", "mockSvc").Return(&ecs.ServiceDesc{
+						ClusterName: mockCluster,
+						Name:        mockService,
+						Tasks: []*awsecs.Task{
+							{
+								TaskArn:      aws.String("arn:aws:ecs:us-west-2:123456789012:task/mockCluster/1234567890123456789"),
+								StartedAt:    &startTime,
+								HealthStatus: aws.String("HEALTHY"),
+								LastStatus:   aws.String("RUNNING"),
+								Containers: []*ecsapi.Container{
+									{
+										Image:       aws.String("mockImageID1"),
+										ImageDigest: aws.String("69671a968e8ec3648e2697417750e"),
+									},
+								},
+								StoppedAt:     &stopTime,
+								StoppedReason: aws.String("some reason"),
+							},
+						},
+					}, nil),
+					m.ecsServiceGetter.EXPECT().Service(mockCluster, mockService).Return(&awsecs.Service{
+						Status:       aws.String("ACTIVE"),
+						DesiredCount: aws.Int64(1),
+						RunningCount: aws.Int64(1),
+						Deployments: []*ecsapi.Deployment{
+							{
+								UpdatedAt:      &startTime,
+								TaskDefinition: aws.String("mockTaskDefinition"),
+							},
+						},
+					}, nil),
+					m.alarmStatusGetter.EXPECT().AlarmsWithTags(map[string]string{
+						"copilot-application": "mockApp",
+						"copilot-environment": "mockEnv",
+						"copilot-service":     "mockSvc",
+					}).Return(nil, nil),
+					m.aas.EXPECT().ECSServiceAlarmNames(mockCluster, mockService).Return(nil, nil),
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return(nil, nil),
+				)
+			},
+
+			wantedContent: &ecsServiceStatus{
+				Service: awsecs.ServiceStatus{
+					DesiredCount: 1,
+					RunningCount: 1,
+					Status:       "ACTIVE",
+					Deployments: []awsecs.Deployment{
+						{
+							UpdatedAt:      startTime,
+							TaskDefinition: "mockTaskDefinition",
+						},
+					},
+					LastDeploymentAt: startTime,
+					TaskDefinition:   "mockTaskDefinition",
+				},
+				Alarms: []cloudwatch.AlarmStatus{},
+				DesiredRunningTasks: []awsecs.TaskStatus{
+					{
+						Health:     "HEALTHY",
+						LastStatus: "RUNNING",
+						ID:         "1234567890123456789",
+						Images: []awsecs.Image{
+							{
+								Digest: "69671a968e8ec3648e2697417750e",
+								ID:     "mockImageID1",
+							},
+						},
+						StartedAt:     startTime,
+						StoppedAt:     stopTime,
+						StoppedReason: "some reason",
+					},
+				},
+			},
+		},
 		"do not error out if failed to get a service's target group health": {
 			setupMocks: func(m serviceStatusDescriberMocks) {
 				gomock.InOrder(
@@ -172,7 +262,7 @@ func TestServiceStatus_Describe(t *testing.T) {
 					}, nil),
 					m.alarmStatusGetter.EXPECT().AlarmsWithTags(gomock.Any()).Return([]cloudwatch.AlarmStatus{}, nil),
 					m.aas.EXPECT().ECSServiceAlarmNames(gomock.Any(), gomock.Any()).Return([]string{}, nil),
-					m.alarmStatusGetter.EXPECT().AlarmStatus(gomock.Any()).Return([]cloudwatch.AlarmStatus{}, nil),
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return(nil, nil),
 					m.targetHealthGetter.EXPECT().TargetsHealth("group-1").Return(nil, errors.New("some error")),
 				)
 			},
@@ -185,7 +275,7 @@ func TestServiceStatus_Describe(t *testing.T) {
 					},
 					LastDeploymentAt: startTime,
 				},
-				Alarms: nil,
+				Alarms: []cloudwatch.AlarmStatus{},
 				DesiredRunningTasks: []awsecs.TaskStatus{
 					{
 						ID:        "1234567890123456789",
@@ -194,7 +284,6 @@ func TestServiceStatus_Describe(t *testing.T) {
 				},
 				StoppedTasks:             nil,
 				TargetHealthDescriptions: nil,
-				//rendererConfigurer:       &barRendererConfigurer{},
 			},
 		},
 		"retrieve all target health information in service": {
@@ -259,7 +348,7 @@ func TestServiceStatus_Describe(t *testing.T) {
 						"copilot-service":     "mockSvc",
 					}).Return([]cloudwatch.AlarmStatus{}, nil),
 					m.aas.EXPECT().ECSServiceAlarmNames(mockCluster, mockService).Return([]string{}, nil),
-					m.alarmStatusGetter.EXPECT().AlarmStatus([]string{}).Return([]cloudwatch.AlarmStatus{}, nil),
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return(nil, nil),
 					m.targetHealthGetter.EXPECT().TargetsHealth("group-1").Return([]*elbv2.TargetHealth{
 						{
 							Target: &elbv2api.TargetDescription{
@@ -314,7 +403,7 @@ func TestServiceStatus_Describe(t *testing.T) {
 					LastDeploymentAt: startTime,
 					TaskDefinition:   "mockTaskDefinition",
 				},
-				Alarms: nil,
+				Alarms: []cloudwatch.AlarmStatus{},
 				DesiredRunningTasks: []awsecs.TaskStatus{
 					{
 						ID: "task-with-private-ip-being-target",
@@ -406,7 +495,15 @@ func TestServiceStatus_Describe(t *testing.T) {
 					}).Return([]cloudwatch.AlarmStatus{
 						{
 							Arn:          "mockAlarmArn1",
-							Name:         "mockAlarm1",
+							Name:         "AMetricAlarm",
+							Condition:    "mockCondition",
+							Status:       "OK",
+							Type:         "Metric",
+							UpdatedTimes: updateTime,
+						},
+						{
+							Arn:          "mockAlarmArn11",
+							Name:         "BMetricAlarm",
 							Condition:    "mockCondition",
 							Status:       "OK",
 							Type:         "Metric",
@@ -414,16 +511,43 @@ func TestServiceStatus_Describe(t *testing.T) {
 						},
 					}, nil),
 					m.aas.EXPECT().ECSServiceAlarmNames(mockCluster, mockService).Return([]string{"mockAlarm2"}, nil),
-					m.alarmStatusGetter.EXPECT().AlarmStatus([]string{"mockAlarm2"}).Return([]cloudwatch.AlarmStatus{
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return([]cloudwatch.AlarmStatus{
+						{
+							Arn:          "mockAlarmArn22",
+							Name:         "BAutoScalingAlarm",
+							Condition:    "mockCondition",
+							Status:       "OK",
+							Type:         "Metric",
+							UpdatedTimes: updateTime,
+						},
 						{
 							Arn:          "mockAlarmArn2",
-							Name:         "mockAlarm2",
+							Name:         "AAutoScalingAlarm",
 							Condition:    "mockCondition",
 							Status:       "OK",
 							Type:         "Metric",
 							UpdatedTimes: updateTime,
 						},
 					}, nil),
+					m.alarmStatusGetter.EXPECT().AlarmStatuses(gomock.Any()).Return(
+						[]cloudwatch.AlarmStatus{
+							{
+								Arn:          "mockAlarmArn33",
+								Name:         "BmockApp-mockEnv-mockSvc-CopilotRollbackAlarm",
+								Condition:    "mockCondition",
+								Status:       "OK",
+								Type:         "Metric",
+								UpdatedTimes: updateTime,
+							},
+							{
+								Arn:          "mockAlarmArn3",
+								Name:         "AmockApp-mockEnv-mockSvc-CopilotRollbackAlarm",
+								Condition:    "mockCondition",
+								Status:       "OK",
+								Type:         "Metric",
+								UpdatedTimes: updateTime,
+							},
+						}, nil),
 				)
 			},
 
@@ -442,22 +566,54 @@ func TestServiceStatus_Describe(t *testing.T) {
 					TaskDefinition:   "mockTaskDefinition",
 				},
 				Alarms: []cloudwatch.AlarmStatus{
+					{
+						Arn:          "mockAlarmArn2",
+						Condition:    "mockCondition",
+						Name:         "AAutoScalingAlarm",
+						Status:       "OK",
+						Type:         "Auto Scaling",
+						UpdatedTimes: updateTime,
+					},
+					{
+						Arn:          "mockAlarmArn22",
+						Name:         "BAutoScalingAlarm",
+						Condition:    "mockCondition",
+						Status:       "OK",
+						Type:         "Auto Scaling",
+						UpdatedTimes: updateTime,
+					},
 					{
 						Arn:          "mockAlarmArn1",
-						Name:         "mockAlarm1",
+						Name:         "AMetricAlarm",
 						Condition:    "mockCondition",
 						Status:       "OK",
 						Type:         "Metric",
 						UpdatedTimes: updateTime,
 					},
 					{
-						Arn:          "mockAlarmArn2",
+						Arn:          "mockAlarmArn11",
+						Name:         "BMetricAlarm",
 						Condition:    "mockCondition",
-						Name:         "mockAlarm2",
 						Status:       "OK",
 						Type:         "Metric",
 						UpdatedTimes: updateTime,
 					},
+					{
+						Arn:          "mockAlarmArn3",
+						Name:         "AmockApp-mockEnv-mockSvc-CopilotRollbackAlarm",
+						Condition:    "mockCondition",
+						Status:       "OK",
+						Type:         "Rollback",
+						UpdatedTimes: updateTime,
+					},
+					{
+						Arn:          "mockAlarmArn33",
+						Name:         "BmockApp-mockEnv-mockSvc-CopilotRollbackAlarm",
+						Condition:    "mockCondition",
+						Status:       "OK",
+						Type:         "Rollback",
+						UpdatedTimes: updateTime,
+					},
 				},
 				DesiredRunningTasks: []awsecs.TaskStatus{
 					{
@@ -479,7 +635,6 @@ func TestServiceStatus_Describe(t *testing.T) {
 						StoppedReason: "some reason",
 					},
 				},
-				//rendererConfigurer: &barRendererConfigurer{},
 			},
 		},
 	}
