@@ -59,13 +59,14 @@ func New(cmd Cmd) CmdClient {
 // BuildArguments holds the arguments that can be passed while building a container.
 type BuildArguments struct {
 	URI        string            // Required. Location of ECR Repo. Used to generate image name in conjunction with tag.
-	Tags       []string          // Optional. List of tags to apply to the image besides "latest".
+	Tags       []string          // Required. List of tags to apply to the image.
 	Dockerfile string            // Required. Dockerfile to pass to `docker build` via --file flag.
 	Context    string            // Optional. Build context directory to pass to `docker build`.
 	Target     string            // Optional. The target build stage to pass to `docker build`.
 	CacheFrom  []string          // Optional. Images to consider as cache sources to pass to `docker build`
 	Platform   string            // Optional. OS/Arch to pass to `docker build`.
 	Args       map[string]string // Optional. Build args to pass via `--build-arg` flags. Equivalent to ARG directives in dockerfile.
+	Labels     map[string]string // Required. Set metadata for an image.
 }
 
 type dockerConfig struct {
@@ -75,6 +76,13 @@ type dockerConfig struct {
 
 // Build will run a `docker build` command for the given ecr repo URI and build arguments.
 func (c CmdClient) Build(in *BuildArguments) error {
+
+	// Tags must not be empty to build an docker image.
+	if len(in.Tags) == 0 {
+		return &errEmptyImageTags{
+			uri: in.URI,
+		}
+	}
 	dfDir := in.Context
 	if dfDir == "" { // Context wasn't specified use the Dockerfile's directory as context.
 		dfDir = filepath.Dir(in.Dockerfile)
@@ -83,7 +91,6 @@ func (c CmdClient) Build(in *BuildArguments) error {
 	args := []string{"build"}
 
 	// Add additional image tags to the docker build call.
-	args = append(args, "-t", in.URI)
 	for _, tag := range in.Tags {
 		args = append(args, "-t", imageName(in.URI, tag))
 	}
@@ -119,6 +126,17 @@ func (c CmdClient) Build(in *BuildArguments) error {
 		args = append(args, "--build-arg", fmt.Sprintf("%s=%s", k, in.Args[k]))
 	}
 
+	// Add Labels to docker build call.
+	// Collect the keys in a slice to sort for test stability.
+	var labelKeys []string
+	for k := range in.Labels {
+		labelKeys = append(labelKeys, k)
+	}
+	sort.Strings(labelKeys)
+	for _, k := range labelKeys {
+		args = append(args, "--label", fmt.Sprintf("%s=%s", k, in.Labels[k]))
+	}
+
 	args = append(args, dfDir, "-f", in.Dockerfile)
 	// If host platform is not linux/amd64, show the user how the container image is being built; if the build fails (if their docker server doesn't have multi-platform-- and therefore `--platform` capability, for instance) they may see why.
 	if in.Platform != "" {
@@ -146,7 +164,7 @@ func (c CmdClient) Login(uri, username, password string) error {
 
 // Push pushes the images with the specified tags and ecr repository URI, and returns the image digest on success.
 func (c CmdClient) Push(uri string, tags ...string) (digest string, err error) {
-	images := []string{uri}
+	images := []string{}
 	for _, tag := range tags {
 		images = append(images, imageName(uri, tag))
 	}
@@ -161,7 +179,11 @@ func (c CmdClient) Push(uri string, tags ...string) (digest string, err error) {
 		}
 	}
 	buf := new(strings.Builder)
-	if err := c.runner.Run("docker", []string{"inspect", "--format", "'{{json (index .RepoDigests 0)}}'", uri}, exec.Stdout(buf)); err != nil {
+	// The container image will have the same digest regardless of the associated tag.
+	// Pick the first tag and get the image's digest.
+	// For Main container we call  docker inspect --format '{{json (index .RepoDigests 0)}}' uri:latest
+	// For Sidecar container images we call docker inspect --format '{{json (index .RepoDigests 0)}}' uri:<sidecarname>-latest
+	if err := c.runner.Run("docker", []string{"inspect", "--format", "'{{json (index .RepoDigests 0)}}'", imageName(uri, tags[0])}, exec.Stdout(buf)); err != nil {
 		return "", fmt.Errorf("inspect image digest for %s: %w", uri, err)
 	}
 	repoDigest := strings.Trim(strings.TrimSpace(buf.String()), `"'`) // remove new lines and quotes from output
@@ -225,9 +247,6 @@ func (c CmdClient) GetPlatform() (os, arch string, err error) {
 }
 
 func imageName(uri, tag string) string {
-	if tag == "" {
-		return uri // If no tag is specified build with latest.
-	}
 	return fmt.Sprintf("%s:%s", uri, tag)
 }
 
@@ -293,3 +312,11 @@ func userHomeDirectory() string {
 
 	return home
 }
+
+type errEmptyImageTags struct {
+	uri string
+}
+
+func (e *errEmptyImageTags) Error() string {
+	return fmt.Sprintf("tags to reference an image should not be empty for building and pushing into the ECR repository %s", e.uri)
+}
