@@ -18,10 +18,11 @@ import (
 )
 
 type workloadLogsMocks struct {
-	logGetter *mocks.MocklogGetter
+	logGetter        *mocks.MocklogGetter
+	serviceARNGetter *mocks.MockserviceARNGetter
 }
 
-func TestWorkloadClient_WriteLogEvents(t *testing.T) {
+func TestECSServiceLogger_WriteLogEvents(t *testing.T) {
 	const (
 		mockLogGroupName     = "mockLogGroup"
 		logEventsHumanString = `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
@@ -30,10 +31,7 @@ firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warnin
 `
 		logEventsJSONString = "{\"logStreamName\":\"firelens_log_router/fcfe4ab8043841c08162318e5ad805f1\",\"ingestionTime\":0,\"message\":\"10.0.0.00 - - [01/Jan/1970 01:01:01] \\\"GET / HTTP/1.1\\\" 200 -\",\"timestamp\":0}\n{\"logStreamName\":\"firelens_log_router/fcfe4ab8043841c08162318e5ad805f1\",\"ingestionTime\":0,\"message\":\"10.0.0.00 - - [01/Jan/1970 01:01:01] \\\"FATA some error\\\" - -\",\"timestamp\":0}\n{\"logStreamName\":\"firelens_log_router/fcfe4ab8043841c08162318e5ad805f1\",\"ingestionTime\":0,\"message\":\"10.0.0.00 - - [01/Jan/1970 01:01:01] \\\"WARN some warning\\\" - -\",\"timestamp\":0}\n"
 	)
-	mockLastEventTime := map[string]int64{
-		"mockLogStreamName": 123456,
-	}
-	logEvents := []*cloudwatchlogs.Event{
+	mockLogEvents := []*cloudwatchlogs.Event{
 		{
 			LogStreamName: "firelens_log_router/fcfe4ab8043841c08162318e5ad805f1",
 			Message:       `10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -`,
@@ -47,103 +45,103 @@ firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warnin
 			Message:       `10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -`,
 		},
 	}
-	moreLogEvents := []*cloudwatchlogs.Event{
+	mockMoreLogEvents := []*cloudwatchlogs.Event{
 		{
 			LogStreamName: "firelens_log_router/fcfe4ab8043841c08162318e5ad805f1",
 			Message:       `10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 404 -`,
 		},
 	}
-	mockLimit := aws.Int64(100)
-	var mockNilLimit *int64
-	mockStartTime := aws.Int64(123456789)
 	mockCurrentTimestamp := time.Date(2020, 11, 23, 0, 0, 0, 0, time.UTC) // Copilot GA date :).
 	testCases := map[string]struct {
-		follow              bool
-		last                int
-		limit               *int64
-		startTime           *int64
-		jsonOutput          bool
-		taskIDs             []string
-		includeStateMachine bool
-		containerName       string
-		setupMocks          func(mocks workloadLogsMocks)
+		follow        bool
+		limit         *int64
+		startTime     *int64
+		jsonOutput    bool
+		taskIDs       []string
+		containerName string
+		setupMocks    func(mocks workloadLogsMocks)
 
 		wantedError   error
 		wantedContent string
 	}{
 		"failed to get task log events": {
 			setupMocks: func(m workloadLogsMocks) {
-				gomock.InOrder(
-					m.logGetter.EXPECT().LogEvents(gomock.Any()).
-						Return(nil, errors.New("some error")),
-				)
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).Return(nil, errors.New("some error"))
 			},
-
 			wantedError: fmt.Errorf("get log events for log group mockLogGroup: some error"),
 		},
 		"success with human output": {
-			limit: mockLimit,
+			limit: aws.Int64(100),
 			setupMocks: func(m workloadLogsMocks) {
-				gomock.InOrder(
-					m.logGetter.EXPECT().LogEvents(gomock.Any()).
-						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.Limit, mockLimit)
-						}).Return(&cloudwatchlogs.LogEventsOutput{
-						Events: logEvents,
-					}, nil),
-				)
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.Limit, aws.Int64(100))
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: mockLogEvents,
+					}, nil)
 			},
-
 			wantedContent: logEventsHumanString,
 		},
 		"success with json output": {
 			jsonOutput: true,
-			startTime:  mockStartTime,
+			startTime:  aws.Int64(123456789),
 			setupMocks: func(m workloadLogsMocks) {
-				gomock.InOrder(
-					m.logGetter.EXPECT().LogEvents(gomock.Any()).
-						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.Limit, mockNilLimit)
-						}).
-						Return(&cloudwatchlogs.LogEventsOutput{
-							Events: logEvents,
-						}, nil),
-				)
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.Limit, (*int64)(nil))
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: mockLogEvents,
+					}, nil)
 			},
-
 			wantedContent: logEventsJSONString,
 		},
 		"success with follow flag": {
-			follow:  true,
-			taskIDs: []string{"mockTaskID1", "mockTaskID2"},
+			follow: true,
 			setupMocks: func(m workloadLogsMocks) {
 				gomock.InOrder(
 					m.logGetter.EXPECT().LogEvents(gomock.Any()).
 						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/mockSvc/mockTaskID1", "copilot/mockSvc/mockTaskID2"})
-							var val *int64 = nil // Explicitly mark that nil is of type *int64 otherwise require.Equal returns an error.
-							require.Equal(t, param.Limit, val)
+							require.Equal(t, param.Limit, (*int64)(nil))
 							require.Equal(t, param.StartTime, aws.Int64(mockCurrentTimestamp.UnixMilli()))
 						}).
 						Return(&cloudwatchlogs.LogEventsOutput{
-							Events:              logEvents,
-							StreamLastEventTime: mockLastEventTime,
+							Events: mockLogEvents,
+							StreamLastEventTime: map[string]int64{
+								"mockLogStreamName": 123456,
+							},
 						}, nil),
 					m.logGetter.EXPECT().LogEvents(gomock.Any()).
 						Return(&cloudwatchlogs.LogEventsOutput{
-							Events:              moreLogEvents,
+							Events:              mockMoreLogEvents,
 							StreamLastEventTime: nil,
 						}, nil),
 				)
 			},
-
 			wantedContent: `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
 firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
 firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
 firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 404 -
 `,
 		},
-		"success with no filtering": {
+		"success with log limit set": {
+			limit: aws.Int64(50),
+			setupMocks: func(m workloadLogsMocks) {
+				gomock.InOrder(
+					m.logGetter.EXPECT().LogEvents(gomock.Any()).
+						Do(func(param cloudwatchlogs.LogEventsOpts) {
+							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/"})
+							require.Equal(t, param.Limit, aws.Int64(50))
+						}).
+						Return(&cloudwatchlogs.LogEventsOutput{
+							Events: mockLogEvents,
+						}, nil),
+				)
+			},
+			wantedContent: logEventsHumanString,
+		},
+		"success when filtered by task IDs": {
 			taskIDs: []string{"mockTaskID1"},
 			setupMocks: func(m workloadLogsMocks) {
 				gomock.InOrder(
@@ -153,79 +151,13 @@ firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1"
 							require.Equal(t, param.Limit, aws.Int64(10))
 						}).
 						Return(&cloudwatchlogs.LogEventsOutput{
-							Events: logEvents,
+							Events: mockLogEvents,
 						}, nil),
 				)
 			},
-
-			wantedContent: `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
-`,
+			wantedContent: logEventsHumanString,
 		},
-		"success with state machine included": {
-			includeStateMachine: true,
-			last:                1,
-			setupMocks: func(m workloadLogsMocks) {
-				gomock.InOrder(
-					m.logGetter.EXPECT().LogEvents(gomock.Any()).
-						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/", "states"})
-							require.Equal(t, param.Limit, mockNilLimit)
-							require.Equal(t, param.LogStreamLimit, 2)
-						}).
-						Return(&cloudwatchlogs.LogEventsOutput{
-							Events: logEvents,
-						}, nil),
-				)
-			},
-			wantedContent: `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
-`,
-		},
-		"success with log stream limit set": {
-			last: 1,
-			setupMocks: func(m workloadLogsMocks) {
-				gomock.InOrder(
-					m.logGetter.EXPECT().LogEvents(gomock.Any()).
-						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/"})
-							require.Equal(t, param.LogStreamLimit, 1)
-							require.Equal(t, param.Limit, mockNilLimit)
-						}).
-						Return(&cloudwatchlogs.LogEventsOutput{
-							Events: logEvents,
-						}, nil),
-				)
-			},
-			wantedContent: `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
-`,
-		},
-		"success with log stream limit and log limit": {
-			last:  1,
-			limit: aws.Int64(50),
-			setupMocks: func(m workloadLogsMocks) {
-				gomock.InOrder(
-					m.logGetter.EXPECT().LogEvents(gomock.Any()).
-						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/"})
-							require.Equal(t, param.LogStreamLimit, 1)
-							require.Equal(t, param.Limit, aws.Int64(50))
-						}).
-						Return(&cloudwatchlogs.LogEventsOutput{
-							Events: logEvents,
-						}, nil),
-				)
-			},
-			wantedContent: `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
-`,
-		},
-		"success with only log stream from certain container": {
+		"success when filtered by certain container and certain tasks": {
 			containerName: "datadog",
 			taskIDs:       []string{"mockTaskID"},
 			setupMocks: func(m workloadLogsMocks) {
@@ -236,14 +168,27 @@ firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warnin
 							require.Equal(t, param.Limit, aws.Int64(10))
 						}).
 						Return(&cloudwatchlogs.LogEventsOutput{
-							Events: logEvents,
+							Events: mockLogEvents,
 						}, nil),
 				)
 			},
-			wantedContent: `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
-firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
-`,
+			wantedContent: logEventsHumanString,
+		},
+		"success when filtered by certain container": {
+			containerName: "datadog",
+			setupMocks: func(m workloadLogsMocks) {
+				gomock.InOrder(
+					m.logGetter.EXPECT().LogEvents(gomock.Any()).
+						Do(func(param cloudwatchlogs.LogEventsOpts) {
+							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/datadog"})
+							require.Equal(t, param.Limit, aws.Int64(10))
+						}).
+						Return(&cloudwatchlogs.LogEventsOutput{
+							Events: mockLogEvents,
+						}, nil),
+				)
+			},
+			wantedContent: logEventsHumanString,
 		},
 	}
 
@@ -261,14 +206,16 @@ firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warnin
 			tc.setupMocks(mocks)
 
 			b := &bytes.Buffer{}
-			svcLogs := &WorkloadClient{
-				name:         "mockSvc",
-				logGroupName: mockLogGroupName,
-				isECS:        true,
-				eventsGetter: mocklogGetter,
-				w:            b,
-				now: func() time.Time {
-					return mockCurrentTimestamp
+			svcLogs := &ECSServiceLogger{
+				workloadLogger: &workloadLogger{
+					app:          "mockApp",
+					env:          "mockEnv",
+					name:         "mockSvc",
+					eventsGetter: mocklogGetter,
+					w:            b,
+					now: func() time.Time {
+						return mockCurrentTimestamp
+					},
 				},
 			}
 
@@ -278,14 +225,13 @@ firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warnin
 				logWriter = WriteJSONLogs
 			}
 			err := svcLogs.WriteLogEvents(WriteLogEventsOpts{
-				Follow:                  tc.follow,
-				TaskIDs:                 tc.taskIDs,
-				Limit:                   tc.limit,
-				StartTime:               tc.startTime,
-				OnEvents:                logWriter,
-				LogStreamLimit:          tc.last,
-				IncludeStateMachineLogs: tc.includeStateMachine,
-				ContainerName:           tc.containerName,
+				Follow:        tc.follow,
+				TaskIDs:       tc.taskIDs,
+				Limit:         tc.limit,
+				StartTime:     tc.startTime,
+				OnEvents:      logWriter,
+				ContainerName: tc.containerName,
+				LogGroup:      mockLogGroupName,
 			})
 
 			// THEN
@@ -299,9 +245,8 @@ firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warnin
 	}
 }
 
-func TestServiceClient_WriteAppRunnerSvcLogEvents(t *testing.T) {
+func TestAppRunnerServiceLogger_WriteLogEvents(t *testing.T) {
 	const (
-		mockLogGroupName     = "mockLogGroup"
 		logEventsHumanString = `instance/85372273718e4806 web-server@1.0.0 start /app
 instance/4e66ee07f2034a7c Server is running on port 4055
 `
@@ -321,32 +266,64 @@ instance/4e66ee07f2034a7c Server is running on port 4055
 	var mockNilLimit *int64
 	mockStartTime := aws.Int64(123456789)
 	testCases := map[string]struct {
-		follow     bool
-		limit      *int64
-		startTime  *int64
-		jsonOutput bool
-		setupMocks func(mocks workloadLogsMocks)
+		follow       bool
+		limit        *int64
+		startTime    *int64
+		jsonOutput   bool
+		logGroupName string
+		setupMocks   func(mocks workloadLogsMocks)
 
 		wantedError   error
 		wantedContent string
 	}{
-		"failed to get log events": {
+		"failed to get service ARN": {
 			setupMocks: func(m workloadLogsMocks) {
-				gomock.InOrder(
-					m.logGetter.EXPECT().LogEvents(gomock.Any()).
-						Return(nil, errors.New("some error")),
-				)
+				m.serviceARNGetter.EXPECT().ServiceARN("mockEnv").Return("", errors.New("some error"))
+			},
+			wantedError: fmt.Errorf("get service ARN for mockSvc: some error"),
+		},
+		"failed to get log events": {
+			logGroupName: "mockLogGroup",
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).Return(nil, errors.New("some error"))
 			},
-
 			wantedError: fmt.Errorf("get log events for log group mockLogGroup: some error"),
 		},
 		"success with human output": {
-			limit: mockLimit,
+			limit:        mockLimit,
+			logGroupName: "mockLogGroup",
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.Limit, mockLimit)
+					}).Return(&cloudwatchlogs.LogEventsOutput{
+					Events: logEvents,
+				}, nil)
+			},
+			wantedContent: logEventsHumanString,
+		},
+		"success with json output": {
+			jsonOutput:   true,
+			startTime:    mockStartTime,
+			logGroupName: "mockLogGroup",
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.Limit, mockNilLimit)
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: logEvents,
+					}, nil)
+			},
+			wantedContent: logEventsJSONString,
+		},
+		"success with application log": {
 			setupMocks: func(m workloadLogsMocks) {
 				gomock.InOrder(
+					m.serviceARNGetter.EXPECT().ServiceARN("mockEnv").Return("arn:aws:apprunner:us-east-1:11111111111:service/mockSvc/mockSvcID", nil),
 					m.logGetter.EXPECT().LogEvents(gomock.Any()).
 						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.Limit, mockLimit)
+							require.Equal(t, param.LogGroup, "/aws/apprunner/mockSvc/mockSvcID/application")
 						}).Return(&cloudwatchlogs.LogEventsOutput{
 						Events: logEvents,
 					}, nil),
@@ -354,21 +331,253 @@ instance/4e66ee07f2034a7c Server is running on port 4055
 			},
 			wantedContent: logEventsHumanString,
 		},
+		"success with system log": {
+			logGroupName: "system",
+			setupMocks: func(m workloadLogsMocks) {
+				gomock.InOrder(
+					m.serviceARNGetter.EXPECT().ServiceARN("mockEnv").Return("arn:aws:apprunner:us-east-1:11111111111:service/mockSvc/mockSvcID", nil),
+					m.logGetter.EXPECT().LogEvents(gomock.Any()).
+						Do(func(param cloudwatchlogs.LogEventsOpts) {
+							require.Equal(t, param.LogGroup, "/aws/apprunner/mockSvc/mockSvcID/service")
+						}).Return(&cloudwatchlogs.LogEventsOutput{
+						Events: logEvents,
+					}, nil),
+				)
+			},
+			wantedContent: logEventsHumanString,
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			m := workloadLogsMocks{
+				logGetter:        mocks.NewMocklogGetter(ctrl),
+				serviceARNGetter: mocks.NewMockserviceARNGetter(ctrl),
+			}
+
+			tc.setupMocks(m)
+
+			b := &bytes.Buffer{}
+			svcLogs := &AppRunnerServiceLogger{
+				workloadLogger: &workloadLogger{
+					app:          "mockApp",
+					env:          "mockEnv",
+					name:         "mockSvc",
+					eventsGetter: m.logGetter,
+					w:            b,
+				},
+				serviceARNGetter: m.serviceARNGetter,
+			}
+
+			// WHEN
+			logWriter := WriteHumanLogs
+			if tc.jsonOutput {
+				logWriter = WriteJSONLogs
+			}
+			err := svcLogs.WriteLogEvents(WriteLogEventsOpts{
+				Follow:    tc.follow,
+				Limit:     tc.limit,
+				StartTime: tc.startTime,
+				LogGroup:  tc.logGroupName,
+				OnEvents:  logWriter,
+			})
+
+			// THEN
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedContent, b.String(), "expected output content match")
+			}
+		})
+	}
+}
+
+func TestJobLogger_WriteLogEvents(t *testing.T) {
+	const (
+		mockLogGroupName     = "mockLogGroup"
+		logEventsHumanString = `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
+firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
+firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
+`
+		logEventsJSONString = "{\"logStreamName\":\"firelens_log_router/fcfe4ab8043841c08162318e5ad805f1\",\"ingestionTime\":0,\"message\":\"10.0.0.00 - - [01/Jan/1970 01:01:01] \\\"GET / HTTP/1.1\\\" 200 -\",\"timestamp\":0}\n{\"logStreamName\":\"firelens_log_router/fcfe4ab8043841c08162318e5ad805f1\",\"ingestionTime\":0,\"message\":\"10.0.0.00 - - [01/Jan/1970 01:01:01] \\\"FATA some error\\\" - -\",\"timestamp\":0}\n{\"logStreamName\":\"firelens_log_router/fcfe4ab8043841c08162318e5ad805f1\",\"ingestionTime\":0,\"message\":\"10.0.0.00 - - [01/Jan/1970 01:01:01] \\\"WARN some warning\\\" - -\",\"timestamp\":0}\n"
+	)
+	mockLogEvents := []*cloudwatchlogs.Event{
+		{
+			LogStreamName: "firelens_log_router/fcfe4ab8043841c08162318e5ad805f1",
+			Message:       `10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -`,
+		},
+		{
+			LogStreamName: "firelens_log_router/fcfe4ab8043841c08162318e5ad805f1",
+			Message:       `10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -`,
+		},
+		{
+			LogStreamName: "firelens_log_router/fcfe4ab8043841c08162318e5ad805f1",
+			Message:       `10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -`,
+		},
+	}
+	mockMoreLogEvents := []*cloudwatchlogs.Event{
+		{
+			LogStreamName: "firelens_log_router/fcfe4ab8043841c08162318e5ad805f1",
+			Message:       `10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 404 -`,
+		},
+	}
+	mockCurrentTimestamp := time.Date(2020, 11, 23, 0, 0, 0, 0, time.UTC) // Copilot GA date :).
+	testCases := map[string]struct {
+		follow              bool
+		logStreamLimit      int
+		limit               *int64
+		startTime           *int64
+		jsonOutput          bool
+		taskIDs             []string
+		includeStateMachine bool
+		setupMocks          func(mocks workloadLogsMocks)
+
+		wantedError   error
+		wantedContent string
+	}{
+		"failed to get task log events": {
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).Return(nil, errors.New("some error"))
+			},
+			wantedError: fmt.Errorf("get log events for log group mockLogGroup: some error"),
+		},
+		"success with human output": {
+			limit: aws.Int64(100),
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.Limit, aws.Int64(100))
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: mockLogEvents,
+					}, nil)
+			},
+			wantedContent: logEventsHumanString,
+		},
 		"success with json output": {
 			jsonOutput: true,
-			startTime:  mockStartTime,
+			startTime:  aws.Int64(123456789),
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.Limit, (*int64)(nil))
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: mockLogEvents,
+					}, nil)
+			},
+			wantedContent: logEventsJSONString,
+		},
+		"success with follow flag": {
+			follow: true,
 			setupMocks: func(m workloadLogsMocks) {
 				gomock.InOrder(
 					m.logGetter.EXPECT().LogEvents(gomock.Any()).
 						Do(func(param cloudwatchlogs.LogEventsOpts) {
-							require.Equal(t, param.Limit, mockNilLimit)
+							require.Equal(t, param.Limit, (*int64)(nil))
+							require.Equal(t, param.StartTime, aws.Int64(mockCurrentTimestamp.UnixMilli()))
 						}).
 						Return(&cloudwatchlogs.LogEventsOutput{
-							Events: logEvents,
+							Events: mockLogEvents,
+							StreamLastEventTime: map[string]int64{
+								"mockLogStreamName": 123456,
+							},
+						}, nil),
+					m.logGetter.EXPECT().LogEvents(gomock.Any()).
+						Return(&cloudwatchlogs.LogEventsOutput{
+							Events:              mockMoreLogEvents,
+							StreamLastEventTime: nil,
 						}, nil),
 				)
 			},
-			wantedContent: logEventsJSONString,
+			wantedContent: `firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 200 -
+firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "FATA some error" - -
+firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "WARN some warning" - -
+firelens_log_router/fcfe4 10.0.0.00 - - [01/Jan/1970 01:01:01] "GET / HTTP/1.1" 404 -
+`,
+		},
+		"success with log limit set": {
+			limit: aws.Int64(50),
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/"})
+						require.Equal(t, param.Limit, aws.Int64(50))
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: mockLogEvents,
+					}, nil)
+			},
+			wantedContent: logEventsHumanString,
+		},
+		"success with state machine included": {
+			includeStateMachine: true,
+			logStreamLimit:      1,
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/", "states"})
+						require.Equal(t, param.Limit, (*int64)(nil))
+						require.Equal(t, param.LogStreamLimit, 2)
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: mockLogEvents,
+					}, nil)
+			},
+			wantedContent: logEventsHumanString,
+		},
+		"success with log stream limit set": {
+			logStreamLimit: 1,
+			setupMocks: func(m workloadLogsMocks) {
+				m.logGetter.EXPECT().LogEvents(gomock.Any()).
+					Do(func(param cloudwatchlogs.LogEventsOpts) {
+						require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/"})
+						require.Equal(t, param.LogStreamLimit, 1)
+						require.Equal(t, param.Limit, (*int64)(nil))
+					}).
+					Return(&cloudwatchlogs.LogEventsOutput{
+						Events: mockLogEvents,
+					}, nil)
+			},
+			wantedContent: logEventsHumanString,
+		},
+		"success with log stream limit and log limit": {
+			logStreamLimit: 1,
+			limit:          aws.Int64(50),
+			setupMocks: func(m workloadLogsMocks) {
+				gomock.InOrder(
+					m.logGetter.EXPECT().LogEvents(gomock.Any()).
+						Do(func(param cloudwatchlogs.LogEventsOpts) {
+							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/"})
+							require.Equal(t, param.LogStreamLimit, 1)
+							require.Equal(t, param.Limit, aws.Int64(50))
+						}).
+						Return(&cloudwatchlogs.LogEventsOutput{
+							Events: mockLogEvents,
+						}, nil),
+				)
+			},
+			wantedContent: logEventsHumanString,
+		},
+		"success when filtered by task IDs": {
+			taskIDs: []string{"mockTaskID1"},
+			setupMocks: func(m workloadLogsMocks) {
+				gomock.InOrder(
+					m.logGetter.EXPECT().LogEvents(gomock.Any()).
+						Do(func(param cloudwatchlogs.LogEventsOpts) {
+							require.Equal(t, param.LogStreamPrefixFilters, []string{"copilot/mockSvc/mockTaskID1"})
+							require.Equal(t, param.Limit, aws.Int64(10))
+						}).
+						Return(&cloudwatchlogs.LogEventsOutput{
+							Events: mockLogEvents,
+						}, nil),
+				)
+			},
+			wantedContent: logEventsHumanString,
 		},
 	}
 
@@ -386,10 +595,17 @@ instance/4e66ee07f2034a7c Server is running on port 4055
 			tc.setupMocks(mocks)
 
 			b := &bytes.Buffer{}
-			svcLogs := &WorkloadClient{
-				logGroupName: mockLogGroupName,
-				eventsGetter: mocklogGetter,
-				w:            b,
+			svcLogs := &JobLogger{
+				workloadLogger: &workloadLogger{
+					app:          "mockApp",
+					env:          "mockEnv",
+					name:         "mockSvc",
+					eventsGetter: mocklogGetter,
+					w:            b,
+					now: func() time.Time {
+						return mockCurrentTimestamp
+					},
+				},
 			}
 
 			// WHEN
@@ -398,10 +614,14 @@ instance/4e66ee07f2034a7c Server is running on port 4055
 				logWriter = WriteJSONLogs
 			}
 			err := svcLogs.WriteLogEvents(WriteLogEventsOpts{
-				Follow:    tc.follow,
-				Limit:     tc.limit,
-				StartTime: tc.startTime,
-				OnEvents:  logWriter,
+				Follow:                  tc.follow,
+				TaskIDs:                 tc.taskIDs,
+				Limit:                   tc.limit,
+				StartTime:               tc.startTime,
+				OnEvents:                logWriter,
+				LogStreamLimit:          tc.logStreamLimit,
+				LogGroup:                mockLogGroupName,
+				IncludeStateMachineLogs: tc.includeStateMachine,
 			})
 
 			// THEN
