@@ -114,21 +114,23 @@ environments:
 								Credentials: aws.String("some arn"),
 							}, Port: aws.Uint16(80)},
 						},
-						RoutingRule: RoutingRuleConfigOrBool{
-							RoutingRuleConfiguration: RoutingRuleConfiguration{
-								Alias: Alias{
-									AdvancedAliases: []AdvancedAlias{},
-									StringSliceOrString: StringSliceOrString{
-										StringSlice: []string{
-											"foobar.com",
-											"v1.foobar.com",
+						HTTPOrBool: HTTPOrBool{
+							HTTP: HTTP{
+								Main: RoutingRule{
+									Alias: Alias{
+										AdvancedAliases: []AdvancedAlias{},
+										StringSliceOrString: StringSliceOrString{
+											StringSlice: []string{
+												"foobar.com",
+												"v1.foobar.com",
+											},
 										},
 									},
+									Path:             aws.String("svc"),
+									TargetContainer:  aws.String("frontend"),
+									HealthCheck:      HealthCheckArgsOrString{},
+									AllowedSourceIps: []IPNet{IPNet("10.1.0.0/24"), IPNet("10.1.1.0/24")},
 								},
-								Path:             aws.String("svc"),
-								TargetContainer:  aws.String("frontend"),
-								HealthCheck:      HealthCheckArgsOrString{},
-								AllowedSourceIps: []IPNet{IPNet("10.1.0.0/24"), IPNet("10.1.1.0/24")},
 							},
 						},
 						TaskConfig: TaskConfig{
@@ -744,72 +746,6 @@ func TestRange_Parse(t *testing.T) {
 	}
 }
 
-func Test_ServiceDockerfileBuildRequired(t *testing.T) {
-	testCases := map[string]struct {
-		svc interface{}
-
-		wanted    bool
-		wantedErr error
-	}{
-		"invalid type": {
-			svc: struct{}{},
-
-			wantedErr: fmt.Errorf("manifest does not have required methods BuildRequired()"),
-		},
-		"fail to check": {
-			svc: &LoadBalancedWebService{},
-
-			wantedErr: fmt.Errorf("check if manifest requires building from local Dockerfile: either \"image.build\" or \"image.location\" needs to be specified in the manifest"),
-		},
-		"success with false": {
-			svc: &LoadBalancedWebService{
-				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
-							Image: Image{
-								ImageLocationOrBuild: ImageLocationOrBuild{
-									Location: aws.String("mockLocation"),
-								},
-							},
-						},
-					},
-				},
-			},
-		},
-		"success with true": {
-			svc: &LoadBalancedWebService{
-				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
-							Image: Image{
-								ImageLocationOrBuild: ImageLocationOrBuild{
-									Build: BuildArgsOrString{
-										BuildString: aws.String("mockDockerfile"),
-									},
-								},
-							},
-						},
-					},
-				},
-			},
-			wanted: true,
-		},
-	}
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-
-			got, err := DockerfileBuildRequired(tc.svc)
-
-			if tc.wantedErr != nil {
-				require.EqualError(t, err, tc.wantedErr.Error())
-			} else {
-				require.NoError(t, err)
-				require.Equal(t, tc.wanted, got)
-			}
-		})
-	}
-}
-
 func TestCount_Desired(t *testing.T) {
 	mockRange := IntRangeBand("1-10")
 	testCases := map[string]struct {
@@ -1000,8 +936,8 @@ func TestParsePortMapping(t *testing.T) {
 func TestLoadBalancedWebService_NetworkLoadBalancerTarget(t *testing.T) {
 	testCases := map[string]struct {
 		in                    LoadBalancedWebService
-		wantedTargetContainer string
-		wantedTargetPort      string
+		wantedTargetContainer []string
+		wantedTargetPort      []string
 		wantedErr             error
 	}{
 		"should return primary container name/nlb port as targetContainer/targetPort in case targetContainer and targetPort is not given ": {
@@ -1013,12 +949,19 @@ func TestLoadBalancedWebService_NetworkLoadBalancerTarget(t *testing.T) {
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{},
 					NLBConfig: NetworkLoadBalancerConfiguration{
-						Port: aws.String("80/tcp"),
+						Listener: NetworkLoadBalancerListener{
+							Port: aws.String("80/tcp"),
+						},
+						AdditionalListeners: []NetworkLoadBalancerListener{
+							{
+								Port: aws.String("81/tcp"),
+							},
+						},
 					},
 				},
 			},
-			wantedTargetContainer: "foo",
-			wantedTargetPort:      "80",
+			wantedTargetContainer: []string{"foo", "foo"},
+			wantedTargetPort:      []string{"80", "81"},
 		},
 		"should return targetContainer and targetPort as is if they are given ": {
 			in: LoadBalancedWebService{
@@ -1029,19 +972,31 @@ func TestLoadBalancedWebService_NetworkLoadBalancerTarget(t *testing.T) {
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{},
 					NLBConfig: NetworkLoadBalancerConfiguration{
-						Port:            aws.String("80/tcp"),
-						TargetPort:      aws.Int(81),
-						TargetContainer: aws.String("bar"),
+						Listener: NetworkLoadBalancerListener{
+							Port:            aws.String("80/tcp"),
+							TargetPort:      aws.Int(81),
+							TargetContainer: aws.String("bar"),
+						},
+						AdditionalListeners: []NetworkLoadBalancerListener{
+							{
+								Port:            aws.String("82/tcp"),
+								TargetPort:      aws.Int(83),
+								TargetContainer: aws.String("nginx"),
+							},
+						},
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"bar": {
 							Port: aws.String("8080"),
 						},
+						"nginx": {
+							Port: aws.String("8081"),
+						},
 					},
 				},
 			},
-			wantedTargetContainer: "bar",
-			wantedTargetPort:      "81",
+			wantedTargetContainer: []string{"bar", "nginx"},
+			wantedTargetPort:      []string{"81", "83"},
 		},
 		"should return error if targetPort is of incorrect type": {
 			in: LoadBalancedWebService{
@@ -1052,7 +1007,9 @@ func TestLoadBalancedWebService_NetworkLoadBalancerTarget(t *testing.T) {
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{},
 					NLBConfig: NetworkLoadBalancerConfiguration{
-						Port: aws.String("80/80/80"),
+						Listener: NetworkLoadBalancerListener{
+							Port: aws.String("80/80/80"),
+						},
 					},
 				},
 			},
@@ -1062,12 +1019,15 @@ func TestLoadBalancedWebService_NetworkLoadBalancerTarget(t *testing.T) {
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			targetContainer, targetPort, err := tc.in.NetworkLoadBalancerTarget()
-			if tc.wantedErr != nil {
-				require.EqualError(t, err, tc.wantedErr.Error())
-			} else {
-				require.Equal(t, tc.wantedTargetContainer, targetContainer)
-				require.Equal(t, tc.wantedTargetPort, targetPort)
+			exposedPorts, _ := tc.in.ExposedPorts()
+			for idx, listener := range tc.in.NLBConfig.NLBListeners() {
+				targetContainer, targetPort, err := listener.Target(exposedPorts)
+				if tc.wantedErr != nil {
+					require.EqualError(t, err, tc.wantedErr.Error())
+				} else {
+					require.Equal(t, tc.wantedTargetContainer[idx], targetContainer)
+					require.Equal(t, tc.wantedTargetPort[idx], targetPort)
+				}
 			}
 		})
 	}
