@@ -67,7 +67,7 @@ func TestCDK_Override(t *testing.T) {
 				return "/bin/npm", nil
 			},
 			CommandFn: func(name string, args ...string) *exec.Cmd {
-				return exec.Command("echo", append([]string{name}, args...)...)
+				return exec.Command("echo")
 			},
 		})
 
@@ -117,7 +117,7 @@ func TestCDK_Override(t *testing.T) {
 				return "/bin/npm", nil
 			},
 			CommandFn: func(name string, args ...string) *exec.Cmd {
-				return exec.Command("echo", append([]string{name}, args...)...)
+				return exec.Command("echo", fmt.Sprintf("Description: %s", strings.Join(append([]string{name}, args...), " ")))
 			},
 		})
 
@@ -126,10 +126,10 @@ func TestCDK_Override(t *testing.T) {
 
 		// THEN
 		require.NoError(t, err)
-		require.Equal(t, "npm install\n", buf.String())
-		require.Equal(t, fmt.Sprintf("%s synth --no-version-reporting\n", binPath), string(out))
+		require.Contains(t, buf.String(), "npm install")
+		require.Contains(t, string(out), fmt.Sprintf("%s synth --no-version-reporting", binPath))
 	})
-	t.Run("should return the transformed document", func(t *testing.T) {
+	t.Run("should return the transformed document with CDK metadata stripped and description updated", func(t *testing.T) {
 		buf := new(strings.Builder)
 		cdk := WithCDK("", CDKOpts{
 			ExecWriter: buf,
@@ -138,7 +138,46 @@ func TestCDK_Override(t *testing.T) {
 				return "/bin/npm", nil
 			},
 			CommandFn: func(name string, args ...string) *exec.Cmd {
-				return exec.Command("echo", "sample cloudformation template")
+				return exec.Command("echo", `
+Description: CloudFormation template that represents a load balanced web service on Amazon ECS.
+AWSTemplateFormatVersion: "2010-09-09"
+Metadata:
+  Manifest: |
+    name: admin
+    type: Load Balanced Web Service
+Parameters:
+  AppName:
+    Type: String
+  BootstrapVersion:
+    Type: AWS::SSM::Parameter::Value<String>
+    Default: /cdk-bootstrap/hnb659fds/version
+    Description: Version of the CDK Bootstrap resources in this environment, automatically retrieved from SSM Parameter Store. [cdk:skip]
+Conditions:
+  HasAddons:
+    Fn::Not:
+      - Fn::Equals:
+          - Ref: AddonsTemplateURL
+          - ""
+Resources:
+  LogGroup:
+    Type: AWS::Logs::LogGroup
+Outputs:
+  DiscoveryServiceARN:
+    Description: ARN of the Discovery Service.
+Rules:
+  CheckBootstrapVersion:
+    Assertions:
+      - Assert:
+          Fn::Not:
+            - Fn::Contains:
+                - - "1"
+                  - "2"
+                  - "3"
+                  - "4"
+                  - "5"
+                - Ref: BootstrapVersion
+        AssertDescription: CDK bootstrap stack version 6 required. Please run 'cdk bootstrap' with a recent version of the CDK CLI.
+`)
 			},
 		})
 
@@ -147,35 +186,72 @@ func TestCDK_Override(t *testing.T) {
 
 		// THEN
 		require.NoError(t, err)
-		require.Equal(t, "sample cloudformation template\n", string(out))
+
+		require.Equal(t, `AWSTemplateFormatVersion: "2010-09-09"
+Description: CloudFormation template that represents a load balanced web service on Amazon ECS using AWS Copilot and CDK.
+Metadata:
+  Manifest: |
+    name: admin
+    type: Load Balanced Web Service
+Parameters:
+  AppName:
+    Type: String
+Conditions:
+  HasAddons:
+    Fn::Not:
+      - Fn::Equals:
+          - Ref: AddonsTemplateURL
+          - ""
+Resources:
+  LogGroup:
+    Type: AWS::Logs::LogGroup
+Outputs:
+  DiscoveryServiceARN:
+    Description: ARN of the Discovery Service.
+`, string(out))
 	})
 }
 
 func TestScaffoldWithCDK(t *testing.T) {
-	// GIVEN
-	fs := afero.NewMemMapFs()
-	dir := filepath.Join("copilot", "frontend", "overrides")
+	t.Run("scaffolds files in an empty directory", func(t *testing.T) {
+		// GIVEN
+		fs := afero.NewMemMapFs()
+		dir := filepath.Join("copilot", "frontend", "overrides")
 
-	// WHEN
-	err := ScaffoldWithCDK(fs, dir, []template.CFNResource{
-		{
-			Type:      "AWS::ECS::Service",
-			LogicalID: "Service",
-		},
+		// WHEN
+		err := ScaffoldWithCDK(fs, dir, []template.CFNResource{
+			{
+				Type:      "AWS::ECS::Service",
+				LogicalID: "Service",
+			},
+		})
+
+		// THEN
+		require.NoError(t, err)
+
+		ok, _ := afero.Exists(fs, filepath.Join(dir, "package.json"))
+		require.True(t, ok, "package.json should exist")
+
+		ok, _ = afero.Exists(fs, filepath.Join(dir, "cdk.json"))
+		require.True(t, ok, "cdk.json should exist")
+
+		ok, _ = afero.Exists(fs, filepath.Join(dir, "stack.ts"))
+		require.True(t, ok, "stack.ts should exist")
+
+		ok, _ = afero.Exists(fs, filepath.Join(dir, "bin", "override.ts"))
+		require.True(t, ok, "bin/override.ts should exist")
 	})
+	t.Run("should return an error if the directory is not empty", func(t *testing.T) {
+		// GIVEN
+		fs := afero.NewMemMapFs()
+		dir := filepath.Join("copilot", "frontend", "overrides")
+		_ = fs.MkdirAll(dir, 0755)
+		_ = afero.WriteFile(fs, filepath.Join(dir, "cdk.json"), []byte("content"), 0644)
 
-	// THEN
-	require.NoError(t, err)
+		// WHEN
+		err := ScaffoldWithCDK(fs, dir, nil)
 
-	ok, _ := afero.Exists(fs, filepath.Join(dir, "package.json"))
-	require.True(t, ok, "package.json should exist")
-
-	ok, _ = afero.Exists(fs, filepath.Join(dir, "cdk.json"))
-	require.True(t, ok, "cdk.json should exist")
-
-	ok, _ = afero.Exists(fs, filepath.Join(dir, "stack.ts"))
-	require.True(t, ok, "stack.ts should exist")
-
-	ok, _ = afero.Exists(fs, filepath.Join(dir, "bin", "override.ts"))
-	require.True(t, ok, "bin/override.ts should exist")
+		// THEN
+		require.EqualError(t, err, fmt.Sprintf("directory %q is not empty", dir))
+	})
 }
