@@ -35,7 +35,6 @@ type StackSetStreamer struct {
 
 	subsMu     sync.Mutex
 	subs       []chan StackSetOpEvent
-	done       chan struct{}
 	isDone     bool
 	lastSentOp stackset.Operation
 	curOp      stackset.Operation
@@ -50,13 +49,10 @@ type StackSetStreamer struct {
 // NewStackSetStreamer creates a StackSetStreamer for the given stack set name and operation.
 func NewStackSetStreamer(cfn StackSetDescriber, ssName, opID string, opStartTime time.Time) *StackSetStreamer {
 	return &StackSetStreamer{
-		stackset:    cfn,
-		ssName:      ssName,
-		opID:        opID,
-		opStartTime: opStartTime,
-
-		done: make(chan struct{}),
-
+		stackset:                  cfn,
+		ssName:                    ssName,
+		opID:                      opID,
+		opStartTime:               opStartTime,
 		clock:                     realClock{},
 		rand:                      rand.Intn,
 		instanceSummariesInterval: 250 * time.Millisecond,
@@ -117,25 +113,25 @@ func (s *StackSetStreamer) Subscribe() <-chan StackSetOpEvent {
 	return c
 }
 
-// Fetch retrieves the latest stack set operation and buffers it.
-func (s *StackSetStreamer) Fetch() (next time.Time, err error) {
+// Fetch retrieves and stores the latest CloudFormation stack set operation.
+// If an error occurs from describing stack set operation, returns a wrapped error.
+// Otherwise, returns the time the next Fetch should be attempted and whether or not there are more operations to fetch.
+func (s *StackSetStreamer) Fetch() (next time.Time, done bool, err error) {
 	op, err := s.stackset.DescribeOperation(s.ssName, s.opID)
 	if err != nil {
 		// Check for throttles and wait to try again using the StackSetStreamer's interval.
 		if request.IsErrorThrottle(err) {
 			s.retries += 1
-			return nextFetchDate(s.clock, s.rand, s.retries), nil
+			return nextFetchDate(s.clock, s.rand, s.retries), false, nil
 		}
-		return next, fmt.Errorf("describe operation %q for stack set %q: %w", s.opID, s.ssName, err)
+		return next, false, fmt.Errorf("describe operation %q for stack set %q: %w", s.opID, s.ssName, err)
 	}
-
 	if op.Status.IsCompleted() {
-		// There are no more stack set events, notify there is no need to Fetch again.
-		close(s.done)
+		done = true
 	}
 	s.retries = 0
 	s.curOp = op
-	return nextFetchDate(s.clock, s.rand, s.retries), nil
+	return nextFetchDate(s.clock, s.rand, s.retries), done, nil
 }
 
 // Notify publishes the stack set's operation description to subscribers only
@@ -172,8 +168,3 @@ func (s *StackSetStreamer) Close() {
 	}
 	s.isDone = true
 }
-
-// Done returns a channel that's closed when there are no more events that can be fetched.
-func (s *StackSetStreamer) Done() <-chan struct{} {
-	return s.done
-}
