@@ -1,7 +1,7 @@
 import * as cdk from 'aws-cdk-lib';
 import * as path from 'path';
-{{- range $resourceType := .Resources.UniqueTypes }}
-import { {{$resourceType.ImportName}} as {{$resourceType.ImportShortRename}} } from 'aws-cdk-lib';
+{{- range $import := .Resources.Imports }}
+import { {{$import.ImportName}} as {{$import.ImportShortRename}} } from 'aws-cdk-lib';
 {{- end }}
 
 interface TransformedStackProps extends cdk.StackProps {
@@ -30,7 +30,7 @@ export class TransformedStack extends cdk.Stack {
     // TODO: implement me.
     transform{{$resource.LogicalID}}() {
         const {{lowerInitialLetters $resource.LogicalID}} = this.template.getResource("{{$resource.LogicalID}}") as {{$resource.Type.ImportShortRename}}.{{$resource.Type.L1ConstructName}};
-        throw new error("not implemented");
+        throw new Error("not implemented");
     }
     {{end }}
 }
\ No newline at end of file
