@@ -6,6 +6,7 @@ package progress
 import (
 	"bytes"
 	"fmt"
+	"github.com/aws/copilot-cli/internal/pkg/aws/cloudwatch"
 	"io"
 	"strconv"
 	"sync"
@@ -38,8 +39,9 @@ func ListeningRollingUpdateRenderer(streamer ECSServiceSubscriber, opts RenderOp
 
 type rollingUpdateComponent struct {
 	// Data to render.
-	deployments  []stream.ECSDeployment
-	failureMsgs  []string
+	deployments []stream.ECSDeployment
+	failureMsgs []string
+	alarms      []cloudwatch.AlarmStatus
 
 	// Style configuration for the component.
 	padding           int
@@ -59,6 +61,7 @@ func (c *rollingUpdateComponent) Listen() {
 		if len(c.failureMsgs) > c.maxLenFailureMsgs {
 			c.failureMsgs = c.failureMsgs[len(c.failureMsgs)-c.maxLenFailureMsgs:]
 		}
+		c.alarms = ev.Alarms
 		c.mu.Unlock()
 	}
 	close(c.done)
@@ -82,6 +85,12 @@ func (c *rollingUpdateComponent) Render(out io.Writer) (numLines int, err error)
 	}
 	numLines += nl
 
+	nl, err = c.renderAlarms(buf)
+	if err != nil {
+		return 0, err
+	}
+	numLines += nl
+
 	if _, err := buf.WriteTo(out); err != nil {
 		return 0, fmt.Errorf("render rolling update component to writer: %w", err)
 	}
@@ -149,6 +158,27 @@ func (c *rollingUpdateComponent) renderFailureMsgs(out io.Writer) (numLines int,
 	return renderComponents(out, components)
 }
 
+func (c *rollingUpdateComponent) renderAlarms(out io.Writer) (numLines int, err error) {
+	if len(c.alarms) == 0 {
+		return 0, nil
+	}
+	header := []string{"Name", "State"}
+	var rows [][]string
+	for _, a := range c.alarms {
+		rows = append(rows, []string{
+			a.Name,
+			prettifyAlarmState(a.Status),
+		})
+	}
+	table := newTableComponent(color.Faint.Sprintf("Alarms"), header, rows)
+	table.Padding = c.padding
+	components := []Renderer{
+		&singleLineComponent{}, // Add an empty line before rendering alarms table.
+		table,
+	}
+	return renderComponents(out, components)
+}
+
 func reverseStrings(arr []string) []string {
 	reversed := make([]string, len(arr))
 	copy(reversed, arr)
