@@ -125,66 +125,6 @@ func TestPrompt_GetSecret(t *testing.T) {
 	}
 }
 
-func TestPrompt_MultiSelect(t *testing.T) {
-	mockError := fmt.Errorf("error")
-	mockMessage := "Which dogs are best?"
-	mockFinalMessage := "Best dogs:"
-
-	testCases := map[string]struct {
-		inPrompt Prompt
-		inOpts   []string
-
-		wantValue []string
-		wantError error
-	}{
-		"should return users input": {
-			inPrompt: func(p survey.Prompt, out interface{}, opts ...survey.AskOpt) error {
-				internalPrompt, ok := p.(*prompt)
-				require.True(t, ok, "input prompt should be type *prompt")
-				require.Equal(t, mockFinalMessage, internalPrompt.FinalMessage)
-
-				sel, ok := internalPrompt.prompter.(*survey.MultiSelect)
-				require.True(t, ok, "internal prompt should be type *survey.MultiSelect")
-				require.Equal(t, mockMessage, sel.Message)
-				require.Empty(t, sel.Help)
-				require.NotEmpty(t, sel.Options)
-
-				result, ok := out.(*[]string)
-
-				require.True(t, ok, "type to write user input to should be a string")
-
-				*result = sel.Options
-
-				require.Equal(t, 2, len(opts))
-
-				return nil
-			},
-			inOpts:    []string{"bowie", "clyde", "keno", "cava", "meow"},
-			wantValue: []string{"bowie", "clyde", "keno", "cava", "meow"},
-			wantError: nil,
-		},
-		"should echo error": {
-			inPrompt: func(p survey.Prompt, out interface{}, opts ...survey.AskOpt) error {
-				return mockError
-			},
-			inOpts:    []string{"apple", "orange", "banana"},
-			wantError: mockError,
-		},
-		"should return error if input options list is empty": {
-			inOpts:    []string{},
-			wantError: ErrEmptyOptions,
-		},
-	}
-
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			gotValue, gotError := tc.inPrompt.MultiSelect(mockMessage, "", tc.inOpts, nil, WithFinalMessage(mockFinalMessage))
-
-			require.Equal(t, tc.wantValue, gotValue)
-			require.Equal(t, tc.wantError, gotError)
-		})
-	}
-}
 func TestPrompt_Confirm(t *testing.T) {
 	mockError := fmt.Errorf("error")
 	mockMessage := "Is devx awesome?"
