@@ -74,6 +74,27 @@ func (p Prompt) SelectOption(message, help string, opts []Option, promptCfgs ...
 	return prettified.choice2Value[result], nil
 }
 
+// MultiSelectOptions prompts the user to select multiple options and returns the value field from the options.
+func (p Prompt) MultiSelectOptions(message, help string, opts []Option, promptCfgs ...PromptConfig) ([]string, error) {
+	if len(opts) <= 0 {
+		return nil, ErrEmptyOptions
+	}
+
+	prettified, err := prettifyOptions(opts)
+	if err != nil {
+		return nil, err
+	}
+	choices, err := p.MultiSelect(message, help, prettified.choices, nil, promptCfgs...)
+	if err != nil {
+		return nil, err
+	}
+	values := make([]string, len(choices))
+	for i, choice := range choices {
+		values[i] = prettified.choice2Value[choice]
+	}
+	return values, nil
+}
+
 // SelectOne prompts the user with a list of options to choose from with the arrow keys.
 func (p Prompt) SelectOne(message, help string, options []string, promptCfgs ...PromptConfig) (string, error) {
 	if len(options) <= 0 {
@@ -101,6 +122,38 @@ func (p Prompt) SelectOne(message, help string, options []string, promptCfgs ...
 	return result, err
 }
 
+// MultiSelect prompts the user with a list of options to choose from with the arrow keys and enter key.
+func (p Prompt) MultiSelect(message, help string, options []string, validator ValidatorFunc, promptCfgs ...PromptConfig) ([]string, error) {
+	if len(options) <= 0 {
+		// returns nil slice if error
+		return nil, ErrEmptyOptions
+	}
+	multiselect := &survey.MultiSelect{
+		Message: message,
+		Options: options,
+		Default: options[0],
+	}
+	if help != "" {
+		multiselect.Help = color.Help(help)
+	}
+
+	prompt := &prompt{
+		prompter: multiselect,
+	}
+	for _, cfg := range promptCfgs {
+		cfg(prompt)
+	}
+
+	var result []string
+	var err error
+	if validator == nil {
+		err = p(prompt, &result, stdio(), icons())
+	} else {
+		err = p(prompt, &result, stdio(), validators(validator), icons())
+	}
+	return result, err
+}
+
 type prettyOptions struct {
 	choices      []string
 	choice2Value map[string]string
@@ -137,3 +190,12 @@ func parseValueFromOptionFmt(formatted string) string {
 	}
 	return strings.TrimSpace(formatted)
 }
+
+func parseValuesFromOptions(formatted string) string {
+	options := strings.Split(formatted, ", ")
+	out := make([]string, len(options))
+	for i, option := range options {
+		out[i] = parseValueFromOptionFmt(option)
+	}
+	return strings.Join(out, ", ")
+}
