@@ -187,6 +187,45 @@ func TestPrompt_SelectOption(t *testing.T) {
 	})
 }
 
+func TestPrompt_MultiSelectOptions(t *testing.T) {
+	// GIVEN
+	var p Prompt = func(p survey.Prompt, out interface{}, _ ...survey.AskOpt) error {
+		sel := p.(*prompt).prompter.(*survey.MultiSelect)
+		require.ElementsMatch(t, []string{
+			"Service                    (AWS::ECS::Service)",
+			"DiscoveryService           (AWS::ServiceDiscovery::Service)",
+			"PublicNetworkLoadBalancer  (AWS::ElasticLoadBalancingV2::LoadBalancer)",
+		}, sel.Options)
+		result := out.(*[]string)
+		*result = []string{
+			"Service                    (AWS::ECS::Service)",
+			"PublicNetworkLoadBalancer  (AWS::ElasticLoadBalancingV2::LoadBalancer)",
+		}
+		return nil
+	}
+	opts := []Option{
+		{
+			Value: "Service",
+			Hint:  "AWS::ECS::Service",
+		},
+		{
+			Value: "DiscoveryService",
+			Hint:  "AWS::ServiceDiscovery::Service",
+		},
+		{
+			Value: "PublicNetworkLoadBalancer",
+			Hint:  "AWS::ElasticLoadBalancingV2::LoadBalancer",
+		},
+	}
+
+	// WHEN
+	actual, err := p.MultiSelectOptions("Which resource?", "choose!", opts)
+
+	// THEN
+	require.NoError(t, err)
+	require.Equal(t, []string{"Service", "PublicNetworkLoadBalancer"}, actual)
+}
+
 func TestPrompt_SelectOne(t *testing.T) {
 	mockError := fmt.Errorf("error")
 	mockMessage := "Which droid is best droid?"
@@ -246,3 +285,64 @@ func TestPrompt_SelectOne(t *testing.T) {
 		})
 	}
 }
+
+func TestPrompt_MultiSelect(t *testing.T) {
+	mockError := fmt.Errorf("error")
+	mockMessage := "Which dogs are best?"
+	mockFinalMessage := "Best dogs:"
+
+	testCases := map[string]struct {
+		inPrompt Prompt
+		inOpts   []string
+
+		wantValue []string
+		wantError error
+	}{
+		"should return users input": {
+			inPrompt: func(p survey.Prompt, out interface{}, opts ...survey.AskOpt) error {
+				internalPrompt, ok := p.(*prompt)
+				require.True(t, ok, "input prompt should be type *prompt")
+				require.Equal(t, mockFinalMessage, internalPrompt.FinalMessage)
+
+				sel, ok := internalPrompt.prompter.(*survey.MultiSelect)
+				require.True(t, ok, "internal prompt should be type *survey.MultiSelect")
+				require.Equal(t, mockMessage, sel.Message)
+				require.Empty(t, sel.Help)
+				require.NotEmpty(t, sel.Options)
+
+				result, ok := out.(*[]string)
+
+				require.True(t, ok, "type to write user input to should be a string")
+
+				*result = sel.Options
+
+				require.Equal(t, 2, len(opts))
+
+				return nil
+			},
+			inOpts:    []string{"bowie", "clyde", "keno", "cava", "meow"},
+			wantValue: []string{"bowie", "clyde", "keno", "cava", "meow"},
+			wantError: nil,
+		},
+		"should echo error": {
+			inPrompt: func(p survey.Prompt, out interface{}, opts ...survey.AskOpt) error {
+				return mockError
+			},
+			inOpts:    []string{"apple", "orange", "banana"},
+			wantError: mockError,
+		},
+		"should return error if input options list is empty": {
+			inOpts:    []string{},
+			wantError: ErrEmptyOptions,
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotValue, gotError := tc.inPrompt.MultiSelect(mockMessage, "", tc.inOpts, nil, WithFinalMessage(mockFinalMessage))
+
+			require.Equal(t, tc.wantValue, gotValue)
+			require.Equal(t, tc.wantError, gotError)
+		})
+	}
+}
